Module model

Module model 

The messages and enums that are part of this client library.

Modules

accessory_widget
Defines additional types related to AccessoryWidget.
action_response
Defines additional types related to ActionResponse.
annotation
Defines additional types related to Annotation.
attachment
Defines additional types related to Attachment.
availability
Defines additional types related to Availability.
contextual_add_on_markup
Defines additional types related to ContextualAddOnMarkup.
create_message_notification_options
Defines additional types related to CreateMessageNotificationOptions.
create_message_request
Defines additional types related to CreateMessageRequest.
custom_emoji
Defines additional types related to CustomEmoji.
custom_status
Defines additional types related to CustomStatus.
deletion_metadata
Defines additional types related to DeletionMetadata.
dialog_action
Defines additional types related to DialogAction.
emoji
Defines additional types related to Emoji.
mark_as_active_request
Defines additional types related to MarkAsActiveRequest.
mark_as_do_not_disturb_request
Defines additional types related to MarkAsDoNotDisturbRequest.
meet_space_link_data
Defines additional types related to MeetSpaceLinkData.
membership
Defines additional types related to Membership.
position_section_request
Defines additional types related to PositionSectionRequest.
quoted_message_metadata
Defines additional types related to QuotedMessageMetadata.
rich_link_metadata
Defines additional types related to RichLinkMetadata.
search_messages_request
Defines additional types related to SearchMessagesRequest.
search_spaces_response
Defines additional types related to SearchSpacesResponse.
section
Defines additional types related to Section.
section_item
Defines additional types related to SectionItem.
slash_command_metadata
Defines additional types related to SlashCommandMetadata.
space
Defines additional types related to Space.
space_event
Defines additional types related to SpaceEvent.
space_notification_setting
Defines additional types related to SpaceNotificationSetting.
user
Defines additional types related to User.
user_mention_metadata
Defines additional types related to UserMentionMetadata.
widget_markup
Defines additional types related to WidgetMarkup.

Structs

AccessoryWidget
One or more interactive widgets that appear at the bottom of a message. For details, see Add interactive widgets at the bottom of a message.
ActionResponse
Parameters that a Chat app can use to configure how its response is posted.
ActionStatus
Represents the status for a request to either invoke or submit a dialog.
Annotation
Output only. Annotations can be associated with the plain-text body of the message or with chips that link to Google Workspace resources like Google Docs or Sheets with start_index and length of 0. To add basic formatting to a text message, see Format text messages.
AttachedGif
A GIF image that’s specified by a URL.
Attachment
An attachment in Google Chat.
AttachmentDataRef
A reference to the attachment data.
Audience
A target audience in Google Chat. A target audience represents a group of users within a Google Workspace organization, defined by an administrator. Target audiences are used to configure access and visibility settings for resources, such as making a space discoverable to a specific group of users.
Availability
Represents a user’s current availability information in Google Chat, including their state (for example, Active, Away, Do Not Disturb) and any custom status.
CalendarEventLinkData
Data for Calendar event links.
CardWithId
A card in a Google Chat message.
ChatSpaceLinkData
Data for Chat space links.
CompleteImportSpaceRequest
Request message for completing the import process for a space.
CompleteImportSpaceResponse
Response message for completing the import process for a space.
ContextualAddOnMarkup
The markup for developers to specify the contents of a contextual AddOn.
CreateCustomEmojiRequest
A request to create a custom emoji.
CreateMembershipRequest
Request message for creating a membership.
CreateMessageNotificationOptions
Options for the notification behavior when the message is posted.
CreateMessageRequest
Creates a message.
CreateReactionRequest
Creates a reaction to a message.
CreateSectionRequest
Request message for creating a section.
CreateSpaceRequest
A request to create a named space with no members.
CustomEmoji
Represents a custom emoji.
CustomEmojiMetadata
Annotation metadata for custom emoji.
CustomStatus
Represents a user’s custom status in Google Chat. This includes a short text message with an optional emoji that a user sets to give more context about their availability.
DeleteCustomEmojiRequest
Request for deleting a custom emoji.
DeleteMembershipRequest
Request to delete a membership in a space.
DeleteMessageRequest
Request to delete a message.
DeleteReactionRequest
Deletes a reaction to a message.
DeleteSectionRequest
Request message for deleting a section. Developer Preview.
DeleteSpaceRequest
Request for deleting a space.
DeletionMetadata
Information about a deleted message. A message is deleted when delete_time is set.
Dialog
Wrapper around the card body of the dialog.
DialogAction
Contains a dialog and request status code.
DoNotDisturbMetadata
Metadata associated with the DO_NOT_DISTURB availability state, specifying when the state is set to expire.
DriveDataRef
A reference to the data of a drive attachment.
DriveLinkData
Data for Google Drive links.
Emoji
An emoji that is used as a reaction to a message.
EmojiReactionSummary
The number of people who reacted to a message with a specific emoji.
FindDirectMessageRequest
A request to get direct message space based on the user resource.
FindGroupChatsRequest
A request to get group chat spaces based on user resources.
FindGroupChatsResponse
A response containing group chat spaces with exactly the calling user and the requested users.
ForwardedMetadata
Metadata about the source space from which a message was forwarded.
GetAttachmentRequest
Request to get an attachment.
GetAvailabilityRequest
Request message for the GetAvailability method.
GetCustomEmojiRequest
A request to return a single custom emoji.
GetMembershipRequest
Request to get a membership of a space.
GetMessageRequest
Request to get a message.
GetSpaceEventRequest
Request message for getting a space event.
GetSpaceNotificationSettingRequest
Request message to get space notification setting. Only supports getting notification setting for the calling user.
GetSpaceReadStateRequest
Request message for GetSpaceReadState API.
GetSpaceRequest
A request to return a single space.
GetThreadReadStateRequest
Request message for GetThreadReadStateRequest API.
Group
A Google Group in Google Chat.
ListCustomEmojisRequest
A request to return a list of custom emojis.
ListCustomEmojisResponse
A response to list custom emojis.
ListMembershipsRequest
Request message for listing memberships.
ListMembershipsResponse
Response to list memberships of the space.
ListMessagesRequest
Lists messages in the specified space, that the user is a member of.
ListMessagesResponse
Response message for listing messages.
ListReactionsRequest
Lists reactions to a message.
ListReactionsResponse
Response to a list reactions request.
ListSectionItemsRequest
Request message for listing section items.
ListSectionItemsResponse
Response message for listing section items.
ListSectionsRequest
Request message for listing sections.
ListSectionsResponse
Response message for listing sections.
ListSpaceEventsRequest
Request message for listing space events.
ListSpaceEventsResponse
Response message for listing space events.
ListSpacesRequest
A request to list the spaces the caller is a member of.
ListSpacesResponse
The response for a list spaces request.
MarkAsActiveRequest
Request message for the MarkAsActive method.
MarkAsAwayRequest
Request message for the MarkAsAway method.
MarkAsDoNotDisturbRequest
Request message for the MarkAsDoNotDisturb method.
MatchedUrl
A matched URL in a Chat message. Chat apps can preview matched URLs. For more information, see Preview links.
MeetSpaceLinkData
Data for Meet space links.
Membership
Represents a membership relation in Google Chat, such as whether a user or Chat app is invited to, part of, or absent from a space.
MembershipBatchCreatedEventData
Event payload for multiple new memberships.
MembershipBatchDeletedEventData
Event payload for multiple deleted memberships.
MembershipBatchUpdatedEventData
Event payload for multiple updated memberships.
MembershipCreatedEventData
Event payload for a new membership.
MembershipDeletedEventData
Event payload for a deleted membership.
MembershipUpdatedEventData
Event payload for an updated membership.
Message
A message in a Google Chat space.
MessageBatchCreatedEventData
Event payload for multiple new messages.
MessageBatchDeletedEventData
Event payload for multiple deleted messages.
MessageBatchUpdatedEventData
Event payload for multiple updated messages.
MessageCreatedEventData
Event payload for a new message.
MessageDeletedEventData
Event payload for a deleted message.
MessageUpdatedEventData
Event payload for an updated message.
MoveSectionItemRequest
Request message for moving a section item across sections.
MoveSectionItemResponse
Response message for moving a section item.
PositionSectionRequest
Request message for positioning a section.
PositionSectionResponse
Response message for positioning a section.
QuotedMessageMetadata
Information about a message that another message quotes.
QuotedMessageSnapshot
Provides a snapshot of the content of the quoted message at the time of quoting or forwarding
Reaction
A reaction to a message.
ReactionBatchCreatedEventData
Event payload for multiple new reactions.
ReactionBatchDeletedEventData
Event payload for multiple deleted reactions.
ReactionCreatedEventData
Event payload for a new reaction.
ReactionDeletedEventData
Event payload for a deleted reaction.
RichLinkMetadata
A rich link to a resource. Rich links can be associated with the plain-text body of the message or represent chips that link to Google Workspace resources like Google Docs or Sheets with start_index and length of 0.
SearchMessageResult
A single result item from a message search.
SearchMessagesRequest
Request message for searching messages.
SearchMessagesResponse
Response message for searching messages.
SearchSpacesRequest
Request to search for a list of spaces based on a query.
SearchSpacesResponse
Response with a list of spaces corresponding to the search spaces request.
Section
Represents a section in Google Chat. Sections help users organize their spaces. There are two types of sections:
SectionItem
A user’s defined section item. This is used to represent section items, such as spaces, grouped under a section.
SetUpSpaceRequest
Request to create a space and add specified users to it.
SlashCommand
Metadata about a slash command in Google Chat.
SlashCommandMetadata
Annotation metadata for slash commands (/).
Space
A space in Google Chat. Spaces are conversations between two or more users or 1:1 messages between a user and a Chat app.
SpaceBatchUpdatedEventData
Event payload for multiple updates to a space.
SpaceEvent
An event that represents a change or activity in a Google Chat space. To learn more, see Work with events from Google Chat.
SpaceNotificationSetting
The notification setting of a user in a space.
SpaceReadState
A user’s read state within a space, used to identify read and unread messages.
SpaceUpdatedEventData
Event payload for an updated space.
Thread
A thread in a Google Chat space. For example usage, see Start or reply to a message thread.
ThreadReadState
A user’s read state within a thread, used to identify read and unread messages.
UpdateAvailabilityRequest
Request message for the UpdateAvailability method.
UpdateMembershipRequest
Request message for updating a membership.
UpdateMessageRequest
Request to update a message.
UpdateSectionRequest
Request message for updating a section.
UpdateSpaceNotificationSettingRequest
Request to update the space notification settings. Only supports updating notification setting for the calling user.
UpdateSpaceReadStateRequest
Request message for UpdateSpaceReadState API.
UpdateSpaceRequest
A request to update a single space.
UploadAttachmentRequest
Request to upload an attachment.
UploadAttachmentResponse
Response of uploading an attachment.
User
A user in Google Chat. When returned as an output from a request, if your Chat app authenticates as a user, the output for a User resource only populates the user’s name and type.
UserMentionMetadata
Annotation metadata for user mentions (@).
WidgetMarkup
A widget is a UI element that presents text and images.

Enums

AnnotationType
Type of the annotation.
HistoryState
The history state for messages and spaces. Specifies how long messages and conversation threads are kept after creation.
MarkupSyntax
Specifies the markup syntax used to format the Chat message text. Applies to the text field of the Message resource.
SpaceView
A view that specifies which fields should be populated on the Space resource. To ensure compatibility with future releases, we recommend that your code account for additional values.