#[non_exhaustive]pub enum MessageReplyOption {
Unspecified,
ReplyMessageFallbackToNewThread,
ReplyMessageOrFail,
UnknownValue(UnknownValue),
}Expand description
Specifies how to reply to a message. More states might be added in the future.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Default. Starts a new thread. Using this option ignores any thread
ID or
thread_key that’s included.
ReplyMessageFallbackToNewThread
Creates the message as a reply to the thread specified by thread
ID or
thread_key. If it fails, the
message starts a new thread instead.
ReplyMessageOrFail
Creates the message as a reply to the thread specified by thread
ID or
thread_key. If a new thread_key
is used, a new thread is created. If the message creation fails, a
NOT_FOUND error is returned instead.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using MessageReplyOption::value or MessageReplyOption::name.
Implementations