#[non_exhaustive]pub enum AnnotationType {
Unspecified,
UserMention,
SlashCommand,
RichLink,
CustomEmoji,
UnknownValue(UnknownValue),
}Expand description
Type of the annotation.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
Default value for the enum. Don’t use.
UserMention
A user is mentioned.
SlashCommand
A slash command is invoked.
RichLink
A rich link annotation.
CustomEmoji
A custom emoji annotation.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using AnnotationType::value or AnnotationType::name.
Implementations