#[non_exhaustive]pub enum HistoryState {
Unspecified,
HistoryOff,
HistoryOn,
UnknownValue(UnknownValue),
}Expand description
The history state for messages and spaces. Specifies how long messages and conversation threads are kept after creation.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Default value. Do not use.
HistoryOff
History off. Messages and threads are kept for 24 hours.
HistoryOn
History on. The organization’s Vault retention rules specify for how long messages and threads are kept.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using HistoryState::value or HistoryState::name.
Implementations