#[non_exhaustive]pub enum MarkupSyntax {
Unspecified,
Chat,
Markdown,
UnknownValue(UnknownValue),
}Expand description
Specifies the markup syntax used to format the Chat message text.
Applies to the text field of the Message resource.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Represents the unspecified value.
Chat
Uses Google Chat’s markup syntax. See https://developers.google.com/workspace/chat/format-messages#format-texts for more information.
Markdown
Uses Markdown syntax. This syntax is based on the CommonMark specification, with additional extensions. See https://developers.google.com/workspace/chat/format-messages#format-texts for more information.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using MarkupSyntax::value or MarkupSyntax::name.
Implementations