#[non_exhaustive]pub enum SpaceView {
Unspecified,
ResourceNameOnly,
Expanded,
UnknownValue(UnknownValue),
}Expand description
A view that specifies which fields should be populated on the
Space
resource.
To ensure compatibility with future releases, we recommend that your code
account for additional values.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
The default / unset value.
ResourceNameOnly
Populates only the Space resource name.
Expanded
Populates Space resource fields. Note: the permissionSettings field
will not be populated.
Requests that specify SPACE_VIEW_EXPANDED must include scopes that allow
reading space data, for example,
https://www.googleapis.com/auth/chat.spaces or
https://www.googleapis.com/auth/chat.spaces.readonly.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using SpaceView::value or SpaceView::name.