#[non_exhaustive]pub struct AccessoryWidget {
pub action: Option<Action>,
/* private fields */
}Expand description
One or more interactive widgets that appear at the bottom of a message. For details, see Add interactive widgets at the bottom of a message.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.action: Option<Action>The type of action.
Implementations
Sourceimpl AccessoryWidget
impl AccessoryWidget