#[non_exhaustive]pub struct ActionStatus {
pub status_code: Code,
pub user_facing_message: String,
/* private fields */
}Expand description
Represents the status for a request to either invoke or submit a dialog.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.status_code: CodeThe status code.
user_facing_message: StringThe message to send users about the status of their request.
If unset, a generic message based on the status_code is sent.
Implementations
Sourceimpl ActionStatus
impl ActionStatus
Sourcepub fn set_status_code<T: Into<Code>>(self, v: T) -> Self
pub fn set_status_code<T: Into<Code>>(self, v: T) -> Self
Sets the value of status_code.
Example
ⓘ
use google_cloud_rpc::model::Code;
let x0 = ActionStatus::new().set_status_code(Code::Cancelled);
let x1 = ActionStatus::new().set_status_code(Code::Unknown);
let x2 = ActionStatus::new().set_status_code(Code::InvalidArgument);Sourcepub fn set_user_facing_message<T: Into<String>>(self, v: T) -> Self
pub fn set_user_facing_message<T: Into<String>>(self, v: T) -> Self
Sets the value of user_facing_message.
Example
ⓘ
let x = ActionStatus::new().set_user_facing_message("example");Trait Implementations
Sourceimpl Clone for ActionStatus
impl Clone for ActionStatus
Sourcefn clone(&self) -> ActionStatus
fn clone(&self) -> ActionStatus
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ActionStatus
impl Debug for ActionStatus
Sourceimpl Default for ActionStatus
impl Default for ActionStatus
Sourcefn default() -> ActionStatus
fn default() -> ActionStatus
Returns the “default value” for a type. Read more
Sourceimpl Message for ActionStatus
impl Message for ActionStatus
Sourceimpl PartialEq for ActionStatus
impl PartialEq for ActionStatus
impl StructuralPartialEq for ActionStatus