Annotation

Struct Annotation 

#[non_exhaustive]
pub struct Annotation { pub type: AnnotationType, pub start_index: Option<i32>, pub length: i32, pub metadata: Option<Metadata>, /* private fields */ }
Output only. Annotations can be associated with the plain-text body of the message or with chips that link to Google Workspace resources like Google Docs or Sheets with start_index and length of 0. To add basic formatting to a text message, see Format text messages.

Example plain-text message body:

Hello @FooBot how are you!"

The corresponding annotations metadata:

"annotations":[{
  "type":"USER_MENTION",
  "startIndex":6,
  "length":7,
  "userMention": {
    "user": {
      "name":"users/{user}",
      "displayName":"FooBot",
      "avatarUrl":"https://goo.gl/aeDtrS",
      "type":"BOT"
    },
    "type":"MENTION"
   }
}]

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
type: AnnotationType

The type of this annotation.

start_index: Option<i32>

Start index (0-based, inclusive) in the plain-text message body this annotation corresponds to.

length: i32

Length of the substring in the plain-text message body this annotation corresponds to. If not present, indicates a length of 0.

metadata: Option<Metadata>

Additional metadata about the annotation.

Implementations

Source

impl Annotation

pub fn new() -> Self

Creates a new default instance.

pub fn set_type<T: Into<AnnotationType>>(self, v: T) -> Self

Sets the value of r#type.

Example
use google_chat_v1::model::AnnotationType;
let x0 = Annotation::new().set_type(AnnotationType::UserMention);
let x1 = Annotation::new().set_type(AnnotationType::SlashCommand);
let x2 = Annotation::new().set_type(AnnotationType::RichLink);
pub fn set_start_index<T>(self, v: T) -> Self
where T: Into<i32>,

Sets the value of start_index.

Example
let x = Annotation::new().set_start_index(42);
pub fn set_or_clear_start_index<T>(self, v: Option<T>) -> Self
where T: Into<i32>,

Sets or clears the value of start_index.

Example
let x = Annotation::new().set_or_clear_start_index(Some(42));
let x = Annotation::new().set_or_clear_start_index(None::<i32>);
pub fn set_length<T: Into<i32>>(self, v: T) -> Self

Sets the value of length.

Example
let x = Annotation::new().set_length(42);
pub fn set_metadata<T: Into<Option<Metadata>>>(self, v: T) -> Self

Sets the value of metadata.

Note that all the setters affecting metadata are mutually exclusive.

Example
use google_chat_v1::model::UserMentionMetadata;
let x = Annotation::new().set_metadata(Some(
    google_chat_v1::model::annotation::Metadata::UserMention(UserMentionMetadata::default().into())));
pub fn user_mention(&self) -> Option<&Box<UserMentionMetadata>>

The value of metadata if it holds a UserMention, None if the field is not set or holds a different branch.

pub fn set_user_mention<T: Into<Box<UserMentionMetadata>>>(self, v: T) -> Self

Sets the value of metadata to hold a UserMention.

Note that all the setters affecting metadata are mutually exclusive.

Example
use google_chat_v1::model::UserMentionMetadata;
let x = Annotation::new().set_user_mention(UserMentionMetadata::default()/* use setters */);
assert!(x.user_mention().is_some());
assert!(x.slash_command().is_none());
assert!(x.rich_link_metadata().is_none());
assert!(x.custom_emoji_metadata().is_none());
pub fn slash_command(&self) -> Option<&Box<SlashCommandMetadata>>

The value of metadata if it holds a SlashCommand, None if the field is not set or holds a different branch.

pub fn set_slash_command<T: Into<Box<SlashCommandMetadata>>>(self, v: T) -> Self

Sets the value of metadata to hold a SlashCommand.

Note that all the setters affecting metadata are mutually exclusive.

Example
use google_chat_v1::model::SlashCommandMetadata;
let x = Annotation::new().set_slash_command(SlashCommandMetadata::default()/* use setters */);
assert!(x.slash_command().is_some());
assert!(x.user_mention().is_none());
assert!(x.rich_link_metadata().is_none());
assert!(x.custom_emoji_metadata().is_none());

The value of metadata if it holds a RichLinkMetadata, None if the field is not set or holds a different branch.

Sets the value of metadata to hold a RichLinkMetadata.

Note that all the setters affecting metadata are mutually exclusive.

Example
use google_chat_v1::model::RichLinkMetadata;
let x = Annotation::new().set_rich_link_metadata(RichLinkMetadata::default()/* use setters */);
assert!(x.rich_link_metadata().is_some());
assert!(x.user_mention().is_none());
assert!(x.slash_command().is_none());
assert!(x.custom_emoji_metadata().is_none());
pub fn custom_emoji_metadata(&self) -> Option<&Box<CustomEmojiMetadata>>

The value of metadata if it holds a CustomEmojiMetadata, None if the field is not set or holds a different branch.

pub fn set_custom_emoji_metadata<T: Into<Box<CustomEmojiMetadata>>>( self, v: T, ) -> Self

Sets the value of metadata to hold a CustomEmojiMetadata.

Note that all the setters affecting metadata are mutually exclusive.

Example
use google_chat_v1::model::CustomEmojiMetadata;
let x = Annotation::new().set_custom_emoji_metadata(CustomEmojiMetadata::default()/* use setters */);
assert!(x.custom_emoji_metadata().is_some());
assert!(x.user_mention().is_none());
assert!(x.slash_command().is_none());
assert!(x.rich_link_metadata().is_none());