#[non_exhaustive]pub struct Audience {
pub name: String,
/* private fields */
}Expand description
A target audience in Google Chat. A target audience represents a group of users within a Google Workspace organization, defined by an administrator. Target audiences are used to configure access and visibility settings for resources, such as making a space discoverable to a specific group of users.
For more details, see Target audiences and Make a space discoverable to a target audience.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe resource name of the target
audience who can discover
or join the space. For details, see Make a space
discoverable to a target
audience.
Format: audiences/{audience}
To use the default target audience for the Google Workspace organization,
set to audiences/default.
Implementations