Availability

Struct Availability 

#[non_exhaustive]
pub struct Availability { pub name: String, pub state: State, pub custom_status: Option<CustomStatus>, pub state_metadata: Option<StateMetadata>, /* private fields */ }
Represents a user’s current availability information in Google Chat, including their state (for example, Active, Away, Do Not Disturb) and any custom status.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Identifier. Resource name of the user’s availability.

Format: users/{user}/availability

{user} is the id for the Person in the People API or Admin SDK directory API. For example, users/123456789.

The user’s email address or me can also be used as an alias to refer to the caller. For example, users/user@example.com or users/me.

state: State

Output only. The user’s current availability state.

custom_status: Option<CustomStatus>

Optional. The user’s custom status.

state_metadata: Option<StateMetadata>

Additional metadata associated with the user’s availability state.

Implementations

Source

impl Availability

pub fn new() -> Self

Creates a new default instance.

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = Availability::new().set_name(format!("users/{user_id}/availability"));
pub fn set_state<T: Into<State>>(self, v: T) -> Self

Sets the value of state.

Example
use google_chat_v1::model::availability::State;
let x0 = Availability::new().set_state(State::Active);
let x1 = Availability::new().set_state(State::Idle);
let x2 = Availability::new().set_state(State::Away);
pub fn set_custom_status<T>(self, v: T) -> Self
where T: Into<CustomStatus>,

Sets the value of custom_status.

Example
use google_chat_v1::model::CustomStatus;
let x = Availability::new().set_custom_status(CustomStatus::default()/* use setters */);
pub fn set_or_clear_custom_status<T>(self, v: Option<T>) -> Self
where T: Into<CustomStatus>,

Sets or clears the value of custom_status.

Example
use google_chat_v1::model::CustomStatus;
let x = Availability::new().set_or_clear_custom_status(Some(CustomStatus::default()/* use setters */));
let x = Availability::new().set_or_clear_custom_status(None::<CustomStatus>);
pub fn set_state_metadata<T: Into<Option<StateMetadata>>>(self, v: T) -> Self

Sets the value of state_metadata.

Note that all the setters affecting state_metadata are mutually exclusive.

Example
use google_chat_v1::model::DoNotDisturbMetadata;
let x = Availability::new().set_state_metadata(Some(
    google_chat_v1::model::availability::StateMetadata::DoNotDisturbMetadata(DoNotDisturbMetadata::default().into())));
pub fn do_not_disturb_metadata(&self) -> Option<&Box<DoNotDisturbMetadata>>

The value of state_metadata if it holds a DoNotDisturbMetadata, None if the field is not set or holds a different branch.

pub fn set_do_not_disturb_metadata<T: Into<Box<DoNotDisturbMetadata>>>( self, v: T, ) -> Self

Sets the value of state_metadata to hold a DoNotDisturbMetadata.

Note that all the setters affecting state_metadata are mutually exclusive.

Example
use google_chat_v1::model::DoNotDisturbMetadata;
let x = Availability::new().set_do_not_disturb_metadata(DoNotDisturbMetadata::default()/* use setters */);
assert!(x.do_not_disturb_metadata().is_some());