#[non_exhaustive]pub struct CardWithId {
pub card_id: String,
pub card: Option<Card>,
/* private fields */
}Expand description
A card in a Google Chat message.
Chat apps can create cards with app authentication. As part of the Developer Preview Program, if your Chat app authenticates as a user, it can create card messages. If your Chat app is not part of Developer Preview Program, it can’t create cards with user authentication.
To learn how to create a message that contains cards, see Send a message.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.card_id: StringRequired if the message contains multiple cards. A unique identifier for a card in a message.
card: Option<Card>A card. Maximum size is 32 KB.
Implementations
Sourceimpl CardWithId
impl CardWithId
Sourcepub fn set_card_id<T: Into<String>>(self, v: T) -> Self
pub fn set_card_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_or_clear_card<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_card<T>(self, v: Option<T>) -> Self