CreateMembershipRequest

Struct CreateMembershipRequest 

#[non_exhaustive]
pub struct CreateMembershipRequest { pub parent: String, pub membership: Option<Membership>, pub use_admin_access: bool, /* private fields */ }
Request message for creating a membership.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
parent: String

Required. The resource name of the space for which to create the membership.

Format: spaces/{space}

membership: Option<Membership>

Required. The membership relation to create.

The memberType field must contain a user with the user.name and user.type fields populated. The server will assign a resource name and overwrite anything specified.

When a Chat app creates a membership relation for a human user, it must use certain authorization scopes and set specific values for certain fields:

  • When authenticating as a user, the chat.memberships authorization scope is required.

  • When authenticating as an app, the chat.app.memberships authorization scope is required.

  • Set user.type to HUMAN, and set user.name with format users/{user}, where {user} can be the email address for the user. For users in the same Workspace organization {user} can also be the id of the person from the People API, or the id for the user in the Directory API. For example, if the People API Person profile ID for user@example.com is 123456789, you can add the user to the space by setting the membership.member.name to users/user@example.com or users/123456789.

Inviting users external to the Workspace organization that owns the space requires user authentication.

When a Chat app creates a membership relation for itself, it must authenticate as a user and use the chat.memberships.app scope, set user.type to BOT, and set user.name to users/app.

use_admin_access: bool

Optional. When true, the method runs using the user’s Google Workspace administrator privileges.

The calling user must be a Google Workspace administrator with the manage chat and spaces conversations privilege.

Requires the chat.admin.memberships OAuth 2.0 scope.

Creating app memberships or creating memberships for users outside the administrator’s Google Workspace organization isn’t supported using admin access.

Implementations

Source

impl CreateMembershipRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_parent<T: Into<String>>(self, v: T) -> Self

Sets the value of parent.

Example
let x = CreateMembershipRequest::new().set_parent(format!("spaces/{space_id}"));
pub fn set_membership<T>(self, v: T) -> Self
where T: Into<Membership>,

Sets the value of membership.

Example
use google_chat_v1::model::Membership;
let x = CreateMembershipRequest::new().set_membership(Membership::default()/* use setters */);
pub fn set_or_clear_membership<T>(self, v: Option<T>) -> Self
where T: Into<Membership>,

Sets or clears the value of membership.

Example
use google_chat_v1::model::Membership;
let x = CreateMembershipRequest::new().set_or_clear_membership(Some(Membership::default()/* use setters */));
let x = CreateMembershipRequest::new().set_or_clear_membership(None::<Membership>);
pub fn set_use_admin_access<T: Into<bool>>(self, v: T) -> Self

Sets the value of use_admin_access.

Example
let x = CreateMembershipRequest::new().set_use_admin_access(true);