CreateSpaceRequest

Struct CreateSpaceRequest 

#[non_exhaustive]
pub struct CreateSpaceRequest { pub space: Option<Space>, pub request_id: String, /* private fields */ }
A request to create a named space with no members.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
space: Option<Space>

Required. The displayName and spaceType fields must be populated. Only SpaceType.SPACE and SpaceType.GROUP_CHAT are supported. SpaceType.GROUP_CHAT can only be used if importMode is set to true.

If you receive the error message ALREADY_EXISTS, try a different displayName. An existing space within the Google Workspace organization might already use this display name.

The space name is assigned on the server so anything specified in this field will be ignored.

request_id: String

Optional. A unique identifier for this request. A random UUID is recommended. Specifying an existing request ID returns the space created with that ID instead of creating a new space. Specifying an existing request ID from the same Chat app with a different authenticated user returns an error.

Implementations

Source

impl CreateSpaceRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_space<T>(self, v: T) -> Self
where T: Into<Space>,

Sets the value of space.

Example
use google_chat_v1::model::Space;
let x = CreateSpaceRequest::new().set_space(Space::default()/* use setters */);
pub fn set_or_clear_space<T>(self, v: Option<T>) -> Self
where T: Into<Space>,

Sets or clears the value of space.

Example
use google_chat_v1::model::Space;
let x = CreateSpaceRequest::new().set_or_clear_space(Some(Space::default()/* use setters */));
let x = CreateSpaceRequest::new().set_or_clear_space(None::<Space>);
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self

Sets the value of request_id.

Example
let x = CreateSpaceRequest::new().set_request_id("example");