CustomEmoji

Struct CustomEmoji 

#[non_exhaustive]
pub struct CustomEmoji { pub name: String, pub uid: String, pub emoji_name: String, pub temporary_image_uri: String, pub payload: Option<CustomEmojiPayload>, /* private fields */ }
Represents a custom emoji.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Identifier. The resource name of the custom emoji, assigned by the server.

Format: customEmojis/{customEmoji}

uid: String

Output only. Unique key for the custom emoji resource.

emoji_name: String

Optional. Immutable. User-provided name for the custom emoji, which is unique within the organization.

Required when the custom emoji is created, output only otherwise.

Emoji names must start and end with colons, must be lowercase and can only contain alphanumeric characters, hyphens, and underscores. Hyphens and underscores should be used to separate words and cannot be used consecutively.

Example: :valid-emoji-name:

temporary_image_uri: String

Output only. A temporary image URL for the custom emoji, valid for at least 10 minutes. Note that this is not populated in the response when the custom emoji is created.

payload: Option<CustomEmojiPayload>

Optional. Input only. Payload data. Required when the custom emoji is created.

Implementations

Source

impl CustomEmoji

pub fn new() -> Self

Creates a new default instance.

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = CustomEmoji::new().set_name(format!("customEmojis/{custom_emoji_id}"));
pub fn set_uid<T: Into<String>>(self, v: T) -> Self

Sets the value of uid.

Example
let x = CustomEmoji::new().set_uid("example");
pub fn set_emoji_name<T: Into<String>>(self, v: T) -> Self

Sets the value of emoji_name.

Example
let x = CustomEmoji::new().set_emoji_name("example");
pub fn set_temporary_image_uri<T: Into<String>>(self, v: T) -> Self

Sets the value of temporary_image_uri.

Example
let x = CustomEmoji::new().set_temporary_image_uri("example");
pub fn set_payload<T>(self, v: T) -> Self

Sets the value of payload.

Example
use google_chat_v1::model::custom_emoji::CustomEmojiPayload;
let x = CustomEmoji::new().set_payload(CustomEmojiPayload::default()/* use setters */);
pub fn set_or_clear_payload<T>(self, v: Option<T>) -> Self

Sets or clears the value of payload.

Example
use google_chat_v1::model::custom_emoji::CustomEmojiPayload;
let x = CustomEmoji::new().set_or_clear_payload(Some(CustomEmojiPayload::default()/* use setters */));
let x = CustomEmoji::new().set_or_clear_payload(None::<CustomEmojiPayload>);