#[non_exhaustive]pub struct DeleteMembershipRequest {
pub name: String,
pub use_admin_access: bool,
/* private fields */
}Expand description
Request to delete a membership in a space.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. Resource name of the membership to delete. Chat apps can delete human users’ or their own memberships. Chat apps can’t delete other apps’ memberships.
When deleting a human membership, requires the chat.memberships scope
with user
authentication
or the chat.memberships.app scope with app
authentication
and the spaces/{space}/members/{member} format.
You can use the email as an alias for {member}. For example,
spaces/{space}/members/example@gmail.com where example@gmail.com is the
email of the Google Chat user.
When deleting an app membership, requires the chat.memberships.app scope
and spaces/{space}/members/app format.
Format: spaces/{space}/members/{member} or spaces/{space}/members/app.
use_admin_access: boolOptional. When true, the method runs using the user’s Google Workspace
administrator privileges.
The calling user must be a Google Workspace administrator with the manage chat and spaces conversations privilege.
Requires the chat.admin.memberships OAuth 2.0
scope.
Deleting app memberships in a space isn’t supported using admin access.
Implementations
Sourceimpl DeleteMembershipRequest
impl DeleteMembershipRequest