#[non_exhaustive]pub struct DeleteMessageRequest {
pub name: String,
pub force: bool,
/* private fields */
}Expand description
Request to delete a message.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. Resource name of the message.
Format: spaces/{space}/messages/{message}
If you’ve set a custom ID for your message, you can use the value from the
clientAssignedMessageId field for {message}. For details, see [Name a
message]
(https://developers.google.com/workspace/chat/create-messages#name_a_created_message).
force: boolOptional. When true, deleting a message also deletes its threaded
replies. When false, if a message has threaded replies, deletion fails.
Only applies when authenticating as a user. Has no effect when [authenticating as a Chat app] (https://developers.google.com/workspace/chat/authenticate-authorize-chat-app).
Implementations