#[non_exhaustive]pub struct DeleteSpaceRequest {
pub name: String,
pub use_admin_access: bool,
/* private fields */
}Expand description
Request for deleting a space.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. Resource name of the space to delete.
Format: spaces/{space}
use_admin_access: boolOptional. When true, the method runs using the user’s Google Workspace
administrator privileges.
The calling user must be a Google Workspace administrator with the manage chat and spaces conversations privilege.
Requires the chat.admin.delete OAuth 2.0
scope.
Implementations
Sourceimpl DeleteSpaceRequest
impl DeleteSpaceRequest