#[non_exhaustive]pub struct DialogAction {
pub action_status: Option<ActionStatus>,
pub action: Option<Action>,
/* private fields */
}Expand description
Contains a dialog and request status code.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.action_status: Option<ActionStatus>Input only. Status for a request to either invoke or submit a dialog. Displays a status and message to users, if necessary. For example, in case of an error or success.
action: Option<Action>Action to perform.
Implementations
Sourceimpl DialogAction
impl DialogAction
Sourcepub fn set_action_status<T>(self, v: T) -> Selfwhere
T: Into<ActionStatus>,
pub fn set_action_status<T>(self, v: T) -> Selfwhere
T: Into<ActionStatus>,
Sets the value of action_status.
Example
ⓘ
use google_chat_v1::model::ActionStatus;
let x = DialogAction::new().set_action_status(ActionStatus::default()/* use setters */);Sourcepub fn set_or_clear_action_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<ActionStatus>,
pub fn set_or_clear_action_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<ActionStatus>,
Sets or clears the value of action_status.
Example
ⓘ
use google_chat_v1::model::ActionStatus;
let x = DialogAction::new().set_or_clear_action_status(Some(ActionStatus::default()/* use setters */));
let x = DialogAction::new().set_or_clear_action_status(None::<ActionStatus>);Sourcepub fn set_action<T: Into<Option<Action>>>(self, v: T) -> Self
pub fn set_action<T: Into<Option<Action>>>(self, v: T) -> Self
Sourcepub fn dialog(&self) -> Option<&Box<Dialog>>
pub fn dialog(&self) -> Option<&Box<Dialog>>
The value of action
if it holds a Dialog, None if the field is not set or
holds a different branch.
Sourcepub fn set_dialog<T: Into<Box<Dialog>>>(self, v: T) -> Self
pub fn set_dialog<T: Into<Box<Dialog>>>(self, v: T) -> Self