#[non_exhaustive]pub struct GetAvailabilityRequest {
pub name: String,
/* private fields */
}Expand description
Request message for the GetAvailability method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The resource name of the availability to retrieve.
Format: users/{user}/availability
{user} is the id for the Person in the People API or Admin SDK directory
API. For example, users/123456789.
The user’s email address or me can also be used as an alias to refer to
the caller. For example, users/user@example.com or users/me.
Implementations