#[non_exhaustive]pub struct GetMembershipRequest {
pub name: String,
pub use_admin_access: bool,
/* private fields */
}Expand description
Request to get a membership of a space.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. Resource name of the membership to retrieve.
To get the app’s own membership by using user
authentication,
you can optionally use spaces/{space}/members/app.
Format: spaces/{space}/members/{member} or spaces/{space}/members/app
You can use the user’s email as an alias for {member}. For example,
spaces/{space}/members/example@gmail.com where example@gmail.com is the
email of the Google Chat user.
use_admin_access: boolOptional. When true, the method runs using the user’s Google Workspace
administrator privileges.
The calling user must be a Google Workspace administrator with the manage chat and spaces conversations privilege.
Requires the chat.admin.memberships or chat.admin.memberships.readonly
OAuth 2.0
scopes.
Getting app memberships in a space isn’t supported when using admin access.
Implementations
Sourceimpl GetMembershipRequest
impl GetMembershipRequest