#[non_exhaustive]pub struct GetMessageRequest {
pub name: String,
pub markup_syntax: MarkupSyntax,
/* private fields */
}Expand description
Request to get a message.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. Resource name of the message.
Format: spaces/{space}/messages/{message}
If you’ve set a custom ID for your message, you can use the value from the
clientAssignedMessageId field for {message}. For details, see [Name a
message]
(https://developers.google.com/workspace/chat/create-messages#name_a_created_message).
markup_syntax: MarkupSyntaxOptional. Specifies the desired output syntax for the Chat message
formatted_text field.
Implementations
Sourceimpl GetMessageRequest
impl GetMessageRequest
Sourcepub fn set_markup_syntax<T: Into<MarkupSyntax>>(self, v: T) -> Self
pub fn set_markup_syntax<T: Into<MarkupSyntax>>(self, v: T) -> Self
Sets the value of markup_syntax.
Example
ⓘ
use google_chat_v1::model::MarkupSyntax;
let x0 = GetMessageRequest::new().set_markup_syntax(MarkupSyntax::Chat);
let x1 = GetMessageRequest::new().set_markup_syntax(MarkupSyntax::Markdown);Trait Implementations
Sourceimpl Clone for GetMessageRequest
impl Clone for GetMessageRequest
Sourcefn clone(&self) -> GetMessageRequest
fn clone(&self) -> GetMessageRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetMessageRequest
impl Debug for GetMessageRequest
Sourceimpl Default for GetMessageRequest
impl Default for GetMessageRequest
Sourcefn default() -> GetMessageRequest
fn default() -> GetMessageRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for GetMessageRequest
impl Message for GetMessageRequest
Sourceimpl PartialEq for GetMessageRequest
impl PartialEq for GetMessageRequest
impl StructuralPartialEq for GetMessageRequest