#[non_exhaustive]pub struct GetSpaceReadStateRequest {
pub name: String,
/* private fields */
}Expand description
Request message for GetSpaceReadState API.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. Resource name of the space read state to retrieve.
Only supports getting read state for the calling user.
To refer to the calling user, set one of the following:
-
The
mealias. For example,users/me/spaces/{space}/spaceReadState. -
Their Workspace email address. For example,
users/user@example.com/spaces/{space}/spaceReadState. -
Their user id. For example,
users/123456789/spaces/{space}/spaceReadState.
Format: users/{user}/spaces/{space}/spaceReadState
Implementations