#[non_exhaustive]pub struct ListReactionsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
/* private fields */
}Expand description
Lists reactions to a message.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The message users reacted to.
Format: spaces/{space}/messages/{message}
page_size: i32Optional. The maximum number of reactions returned. The service can return fewer reactions than this value. If unspecified, the default value is 25. The maximum value is 200; values above 200 are changed to 200.
page_token: StringOptional. (If resuming from a previous query.)
A page token received from a previous list reactions call. Provide this to retrieve the subsequent page.
When paginating, the filter value should match the call that provided the page token. Passing a different value might lead to unexpected results.
filter: StringOptional. A query filter.
You can filter reactions by
emoji
(either emoji.unicode or emoji.custom_emoji.uid) and
user
(user.name).
To filter reactions for multiple emojis or users, join similar fields
with the OR operator, such as emoji.unicode = "🙂" OR emoji.unicode = "👍" and user.name = "users/AAAAAA" OR user.name = "users/BBBBBB".
To filter reactions by emoji and user, use the AND operator, such as
emoji.unicode = "🙂" AND user.name = "users/AAAAAA".
If your query uses both AND and OR, group them with parentheses.
For example, the following queries are valid:
user.name = "users/{user}"
emoji.unicode = "🙂"
emoji.custom_emoji.uid = "{uid}"
emoji.unicode = "🙂" OR emoji.unicode = "👍"
emoji.unicode = "🙂" OR emoji.custom_emoji.uid = "{uid}"
emoji.unicode = "🙂" AND user.name = "users/{user}"
(emoji.unicode = "🙂" OR emoji.custom_emoji.uid = "{uid}")
AND user.name = "users/{user}"The following queries are invalid:
emoji.unicode = "🙂" AND emoji.unicode = "👍"
emoji.unicode = "🙂" AND emoji.custom_emoji.uid = "{uid}"
emoji.unicode = "🙂" OR user.name = "users/{user}"
emoji.unicode = "🙂" OR emoji.custom_emoji.uid = "{uid}" OR
user.name = "users/{user}"
emoji.unicode = "🙂" OR emoji.custom_emoji.uid = "{uid}"
AND user.name = "users/{user}"Invalid queries are rejected with an INVALID_ARGUMENT error.
Implementations
Sourceimpl ListReactionsRequest
impl ListReactionsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListReactionsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListReactionsRequest
impl Clone for ListReactionsRequest
Sourcefn clone(&self) -> ListReactionsRequest
fn clone(&self) -> ListReactionsRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more