ListSectionItemsRequest

Struct ListSectionItemsRequest 

#[non_exhaustive]
pub struct ListSectionItemsRequest { pub parent: String, pub page_size: i32, pub page_token: String, pub filter: String, /* private fields */ }
Request message for listing section items.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
parent: String

Required. The parent, which is the section resource name that owns this collection of section items. Only supports listing section items for the calling user.

When you’re filtering by space, use the wildcard - to search across all sections. For example, users/{user}/sections/-.

Format: users/{user}/sections/{section}

page_size: i32

Optional. The maximum number of section items to return. The service may return fewer than this value.

If unspecified, at most 10 section items will be returned.

The maximum value is 100. If you use a value more than 100, it’s automatically changed to 100.

Negative values return an INVALID_ARGUMENT error.

page_token: String

Optional. A page token, received from a previous list section items call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided should match the call that provided the page token. Passing different values to the other parameters might lead to unexpected results.

filter: String

Optional. A query filter.

Currently only supports filtering by space.

For example, space = spaces/{space}.

Invalid queries are rejected with an INVALID_ARGUMENT error.

Implementations

Source

impl ListSectionItemsRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_parent<T: Into<String>>(self, v: T) -> Self

Sets the value of parent.

Example
let x = ListSectionItemsRequest::new().set_parent(format!("users/{user_id}/sections/{section_id}"));
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self

Sets the value of page_size.

Example
let x = ListSectionItemsRequest::new().set_page_size(42);
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self

Sets the value of page_token.

Example
let x = ListSectionItemsRequest::new().set_page_token("example");
pub fn set_filter<T: Into<String>>(self, v: T) -> Self

Sets the value of filter.

Example
let x = ListSectionItemsRequest::new().set_filter("example");