#[non_exhaustive]pub struct ListSectionsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Expand description
Request message for listing sections.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent, which is the user resource name that owns this collection of sections. Only supports listing sections for the calling user. To refer to the calling user, set one of the following:
-
The
mealias. For example,users/me. -
Their Workspace email address. For example,
users/user@example.com. -
Their user id. For example,
users/123456789.
Format: users/{user}
page_size: i32Optional. The maximum number of sections to return. The service may return fewer than this value.
If unspecified, at most 10 sections will be returned.
The maximum value is 100. If you use a value more than 100, it’s automatically changed to 100.
Negative values return an INVALID_ARGUMENT error.
page_token: StringOptional. A page token, received from a previous list sections call. Provide this to retrieve the subsequent page.
When paginating, all other parameters provided should match the call that provided the page token. Passing different values to the other parameters might lead to unexpected results.
Implementations
Sourceimpl ListSectionsRequest
impl ListSectionsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListSectionsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListSectionsRequest
impl Clone for ListSectionsRequest
Sourcefn clone(&self) -> ListSectionsRequest
fn clone(&self) -> ListSectionsRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more