ListSpacesRequest

Struct ListSpacesRequest 

#[non_exhaustive]
pub struct ListSpacesRequest { pub page_size: i32, pub page_token: String, pub filter: String, /* private fields */ }
A request to list the spaces the caller is a member of.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
page_size: i32

Optional. The maximum number of spaces to return. The service might return fewer than this value.

If unspecified, at most 100 spaces are returned.

The maximum value is 1000. If you use a value more than 1000, it’s automatically changed to 1000.

Negative values return an INVALID_ARGUMENT error.

page_token: String

Optional. A page token, received from a previous list spaces call. Provide this parameter to retrieve the subsequent page.

When paginating, the filter value should match the call that provided the page token. Passing a different value may lead to unexpected results.

filter: String

Optional. A query filter.

You can filter spaces by the space type (space_type).

To filter by space type, you must specify valid enum value, such as SPACE or GROUP_CHAT (the space_type can’t be SPACE_TYPE_UNSPECIFIED). To query for multiple space types, use the OR operator.

For example, the following queries are valid:

space_type = "SPACE"
spaceType = "GROUP_CHAT" OR spaceType = "DIRECT_MESSAGE"

Invalid queries are rejected by the server with an INVALID_ARGUMENT error.

Implementations

Source

impl ListSpacesRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self

Sets the value of page_size.

Example
let x = ListSpacesRequest::new().set_page_size(42);
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self

Sets the value of page_token.

Example
let x = ListSpacesRequest::new().set_page_token("example");
pub fn set_filter<T: Into<String>>(self, v: T) -> Self

Sets the value of filter.

Example
let x = ListSpacesRequest::new().set_filter("example");