Membership

Struct Membership 

#[non_exhaustive]
pub struct Membership { pub name: String, pub state: MembershipState, pub role: MembershipRole, pub create_time: Option<Timestamp>, pub delete_time: Option<Timestamp>, pub affiliation: Affiliation, pub member_type: Option<MemberType>, /* private fields */ }
Represents a membership relation in Google Chat, such as whether a user or Chat app is invited to, part of, or absent from a space.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Identifier. Resource name of the membership, assigned by the server.

Format: spaces/{space}/members/{member}

state: MembershipState

Output only. State of the membership.

role: MembershipRole

Optional. User’s role within a Chat space, which determines their permitted actions in the space.

This field can only be used as input in UpdateMembership.

create_time: Option<Timestamp>

Optional. Immutable. The creation time of the membership, such as when a member joined or was invited to join a space. This field is output only, except when used to import historical memberships in import mode spaces.

delete_time: Option<Timestamp>

Optional. Immutable. The deletion time of the membership, such as when a member left or was removed from a space. This field is output only, except when used to import historical memberships in import mode spaces.

affiliation: Affiliation

Output only. A user’s relationship to the Workspace organization that owns the space. In spaces owned by consumer accounts, the affiliation of all members is EXTERNAL.

member_type: Option<MemberType>

Member associated with this membership. Other member types might be supported in the future.

Implementations

Source

impl Membership

pub fn new() -> Self

Creates a new default instance.

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = Membership::new().set_name(format!("spaces/{space_id}/members/{member_id}"));
pub fn set_state<T: Into<MembershipState>>(self, v: T) -> Self

Sets the value of state.

Example
use google_chat_v1::model::membership::MembershipState;
let x0 = Membership::new().set_state(MembershipState::Joined);
let x1 = Membership::new().set_state(MembershipState::Invited);
let x2 = Membership::new().set_state(MembershipState::NotAMember);
pub fn set_role<T: Into<MembershipRole>>(self, v: T) -> Self

Sets the value of role.

Example
use google_chat_v1::model::membership::MembershipRole;
let x0 = Membership::new().set_role(MembershipRole::RoleMember);
let x1 = Membership::new().set_role(MembershipRole::RoleManager);
let x2 = Membership::new().set_role(MembershipRole::RoleAssistantManager);
pub fn set_create_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of create_time.

Example
use wkt::Timestamp;
let x = Membership::new().set_create_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of create_time.

Example
use wkt::Timestamp;
let x = Membership::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Membership::new().set_or_clear_create_time(None::<Timestamp>);
pub fn set_delete_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of delete_time.

Example
use wkt::Timestamp;
let x = Membership::new().set_delete_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_delete_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of delete_time.

Example
use wkt::Timestamp;
let x = Membership::new().set_or_clear_delete_time(Some(Timestamp::default()/* use setters */));
let x = Membership::new().set_or_clear_delete_time(None::<Timestamp>);
pub fn set_affiliation<T: Into<Affiliation>>(self, v: T) -> Self

Sets the value of affiliation.

Example
use google_chat_v1::model::membership::Affiliation;
let x0 = Membership::new().set_affiliation(Affiliation::Internal);
let x1 = Membership::new().set_affiliation(Affiliation::External);
let x2 = Membership::new().set_affiliation(Affiliation::ManagedExternal);
pub fn set_member_type<T: Into<Option<MemberType>>>(self, v: T) -> Self

Sets the value of member_type.

Note that all the setters affecting member_type are mutually exclusive.

Example
use google_chat_v1::model::User;
let x = Membership::new().set_member_type(Some(
    google_chat_v1::model::membership::MemberType::Member(User::default().into())));
pub fn member(&self) -> Option<&Box<User>>

The value of member_type if it holds a Member, None if the field is not set or holds a different branch.

pub fn set_member<T: Into<Box<User>>>(self, v: T) -> Self

Sets the value of member_type to hold a Member.

Note that all the setters affecting member_type are mutually exclusive.

Example
use google_chat_v1::model::User;
let x = Membership::new().set_member(User::default()/* use setters */);
assert!(x.member().is_some());
assert!(x.group_member().is_none());
pub fn group_member(&self) -> Option<&Box<Group>>

The value of member_type if it holds a GroupMember, None if the field is not set or holds a different branch.

pub fn set_group_member<T: Into<Box<Group>>>(self, v: T) -> Self

Sets the value of member_type to hold a GroupMember.

Note that all the setters affecting member_type are mutually exclusive.

Example
use google_chat_v1::model::Group;
let x = Membership::new().set_group_member(Group::default()/* use setters */);
assert!(x.group_member().is_some());
assert!(x.member().is_none());