#[non_exhaustive]pub struct MoveSectionItemRequest {
pub name: String,
pub target_section: String,
/* private fields */
}Expand description
Request message for moving a section item across sections.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The resource name of the section item to move.
Format: users/{user}/sections/{section}/items/{item}
target_section: StringRequired. The resource name of the section to move the section item to.
Format: users/{user}/sections/{section}
Implementations
Sourceimpl MoveSectionItemRequest
impl MoveSectionItemRequest