#[non_exhaustive]pub struct QuotedMessageSnapshot {
pub sender: String,
pub text: String,
pub formatted_text: String,
pub annotations: Vec<Annotation>,
pub attachments: Vec<Attachment>,
/* private fields */
}Expand description
Provides a snapshot of the content of the quoted message at the time of quoting or forwarding
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.sender: StringOutput only. The quoted message’s author name. Populated for both REPLY & FORWARD quote types.
text: StringOutput only. Snapshot of the quoted message’s text content.
formatted_text: StringOutput only. Contains the quoted message text with markups added to
support rich formatting like hyperlinks,custom emojis, markup, etc.
Populated only for FORWARD quote type.
annotations: Vec<Annotation>Output only. Annotations parsed from the text body of the quoted message. Populated only for FORWARD quote type.
attachments: Vec<Attachment>Output only. Attachments that were part of the quoted message. These are copies of the quoted message’s attachment metadata. Populated only for FORWARD quote type.
Implementations
Sourceimpl QuotedMessageSnapshot
impl QuotedMessageSnapshot
Sourcepub fn set_sender<T: Into<String>>(self, v: T) -> Self
pub fn set_sender<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_formatted_text<T: Into<String>>(self, v: T) -> Self
pub fn set_formatted_text<T: Into<String>>(self, v: T) -> Self
Sets the value of formatted_text.
Example
let x = QuotedMessageSnapshot::new().set_formatted_text("example");Sourcepub fn set_annotations<T, V>(self, v: T) -> Self
pub fn set_annotations<T, V>(self, v: T) -> Self
Sets the value of annotations.
Example
use google_chat_v1::model::Annotation;
let x = QuotedMessageSnapshot::new()
.set_annotations([
Annotation::default()/* use setters */,
Annotation::default()/* use (different) setters */,
]);Sourcepub fn set_attachments<T, V>(self, v: T) -> Self
pub fn set_attachments<T, V>(self, v: T) -> Self
Sets the value of attachments.
Example
use google_chat_v1::model::Attachment;
let x = QuotedMessageSnapshot::new()
.set_attachments([
Attachment::default()/* use setters */,
Attachment::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for QuotedMessageSnapshot
impl Clone for QuotedMessageSnapshot
Sourcefn clone(&self) -> QuotedMessageSnapshot
fn clone(&self) -> QuotedMessageSnapshot
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more