RichLinkMetadata

Struct RichLinkMetadata 

#[non_exhaustive]
pub struct RichLinkMetadata { pub uri: String, pub rich_link_type: RichLinkType, pub data: Option<Data>, /* private fields */ }
A rich link to a resource. Rich links can be associated with the plain-text body of the message or represent chips that link to Google Workspace resources like Google Docs or Sheets with start_index and length of 0.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
uri: String

The URI of this link.

rich_link_type: RichLinkType

The rich link type.

data: Option<Data>

Data for the linked resource.

Implementations

Source

impl RichLinkMetadata

pub fn new() -> Self

Creates a new default instance.

pub fn set_uri<T: Into<String>>(self, v: T) -> Self

Sets the value of uri.

Example
let x = RichLinkMetadata::new().set_uri("example");

Sets the value of rich_link_type.

Example
use google_chat_v1::model::rich_link_metadata::RichLinkType;
let x0 = RichLinkMetadata::new().set_rich_link_type(RichLinkType::DriveFile);
let x1 = RichLinkMetadata::new().set_rich_link_type(RichLinkType::ChatSpace);
let x2 = RichLinkMetadata::new().set_rich_link_type(RichLinkType::GmailMessage);
pub fn set_data<T: Into<Option<Data>>>(self, v: T) -> Self

Sets the value of data.

Note that all the setters affecting data are mutually exclusive.

Example
use google_chat_v1::model::DriveLinkData;
let x = RichLinkMetadata::new().set_data(Some(
    google_chat_v1::model::rich_link_metadata::Data::DriveLinkData(DriveLinkData::default().into())));

The value of data if it holds a DriveLinkData, None if the field is not set or holds a different branch.

Sets the value of data to hold a DriveLinkData.

Note that all the setters affecting data are mutually exclusive.

Example
use google_chat_v1::model::DriveLinkData;
let x = RichLinkMetadata::new().set_drive_link_data(DriveLinkData::default()/* use setters */);
assert!(x.drive_link_data().is_some());
assert!(x.chat_space_link_data().is_none());
assert!(x.meet_space_link_data().is_none());
assert!(x.calendar_event_link_data().is_none());

The value of data if it holds a ChatSpaceLinkData, None if the field is not set or holds a different branch.

Sets the value of data to hold a ChatSpaceLinkData.

Note that all the setters affecting data are mutually exclusive.

Example
use google_chat_v1::model::ChatSpaceLinkData;
let x = RichLinkMetadata::new().set_chat_space_link_data(ChatSpaceLinkData::default()/* use setters */);
assert!(x.chat_space_link_data().is_some());
assert!(x.drive_link_data().is_none());
assert!(x.meet_space_link_data().is_none());
assert!(x.calendar_event_link_data().is_none());

The value of data if it holds a MeetSpaceLinkData, None if the field is not set or holds a different branch.

Sets the value of data to hold a MeetSpaceLinkData.

Note that all the setters affecting data are mutually exclusive.

Example
use google_chat_v1::model::MeetSpaceLinkData;
let x = RichLinkMetadata::new().set_meet_space_link_data(MeetSpaceLinkData::default()/* use setters */);
assert!(x.meet_space_link_data().is_some());
assert!(x.drive_link_data().is_none());
assert!(x.chat_space_link_data().is_none());
assert!(x.calendar_event_link_data().is_none());

The value of data if it holds a CalendarEventLinkData, None if the field is not set or holds a different branch.

Sets the value of data to hold a CalendarEventLinkData.

Note that all the setters affecting data are mutually exclusive.

Example
use google_chat_v1::model::CalendarEventLinkData;
let x = RichLinkMetadata::new().set_calendar_event_link_data(CalendarEventLinkData::default()/* use setters */);
assert!(x.calendar_event_link_data().is_some());
assert!(x.drive_link_data().is_none());
assert!(x.chat_space_link_data().is_none());
assert!(x.meet_space_link_data().is_none());