SearchMessageResult

Struct SearchMessageResult 

#[non_exhaustive]
pub struct SearchMessageResult { pub message: Option<Message>, pub read: Option<bool>, pub space_mute_setting: MuteSetting, /* private fields */ }
A single result item from a message search.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
message: Option<Message>

The matched message.

read: Option<bool>

Indicates if the matched message is read by the calling user.

Only returned if the request view is SEARCH_MESSAGES_VIEW_FULL and the calling credentials include one of the following authorization scopes:

  • <https://www.googleapis.com/auth/chat.users.readstate.readonly>
  • <https://www.googleapis.com/auth/chat.users.readstate>
space_mute_setting: MuteSetting

The mute setting of the calling user for the space where the message is posted. The caller app can use this information to decide how to process the message depending on whether the space is muted for the user or not.

Only returned if the request view is SEARCH_MESSAGES_VIEW_FULL and the calling credentials include the following authorization scope:

  • <https://www.googleapis.com/auth/chat.users.spacesettings>

Implementations

Source

impl SearchMessageResult

pub fn new() -> Self

Creates a new default instance.

pub fn set_message<T>(self, v: T) -> Self
where T: Into<Message>,

Sets the value of message.

Example
use google_chat_v1::model::Message;
let x = SearchMessageResult::new().set_message(Message::default()/* use setters */);
pub fn set_or_clear_message<T>(self, v: Option<T>) -> Self
where T: Into<Message>,

Sets or clears the value of message.

Example
use google_chat_v1::model::Message;
let x = SearchMessageResult::new().set_or_clear_message(Some(Message::default()/* use setters */));
let x = SearchMessageResult::new().set_or_clear_message(None::<Message>);
pub fn set_read<T>(self, v: T) -> Self
where T: Into<bool>,

Sets the value of read.

Example
let x = SearchMessageResult::new().set_read(true);
pub fn set_or_clear_read<T>(self, v: Option<T>) -> Self
where T: Into<bool>,

Sets or clears the value of read.

Example
let x = SearchMessageResult::new().set_or_clear_read(Some(false));
let x = SearchMessageResult::new().set_or_clear_read(None::<bool>);
pub fn set_space_mute_setting<T: Into<MuteSetting>>(self, v: T) -> Self

Sets the value of space_mute_setting.

Example
use google_chat_v1::model::space_notification_setting::MuteSetting;
let x0 = SearchMessageResult::new().set_space_mute_setting(MuteSetting::Unmuted);
let x1 = SearchMessageResult::new().set_space_mute_setting(MuteSetting::Muted);