#[non_exhaustive]pub struct SearchMessagesResponse {
pub results: Vec<SearchMessageResult>,
pub next_page_token: String,
/* private fields */
}Expand description
Response message for searching messages.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.results: Vec<SearchMessageResult>The list of search results that matched the query.
next_page_token: StringA token that can be used to retrieve the next page. If this field is empty, there are no subsequent pages.
Implementations
Sourceimpl SearchMessagesResponse
impl SearchMessagesResponse
Sourcepub fn set_results<T, V>(self, v: T) -> Self
pub fn set_results<T, V>(self, v: T) -> Self
Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = SearchMessagesResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for SearchMessagesResponse
impl Clone for SearchMessagesResponse
Sourcefn clone(&self) -> SearchMessagesResponse
fn clone(&self) -> SearchMessagesResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SearchMessagesResponse
impl Debug for SearchMessagesResponse
Sourceimpl Default for SearchMessagesResponse
impl Default for SearchMessagesResponse
Sourcefn default() -> SearchMessagesResponse
fn default() -> SearchMessagesResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for SearchMessagesResponse
impl Message for SearchMessagesResponse
Sourceimpl PartialEq for SearchMessagesResponse
impl PartialEq for SearchMessagesResponse
impl StructuralPartialEq for SearchMessagesResponse