#[non_exhaustive]pub struct SearchSpacesResponse {
pub spaces: Vec<Space>,
pub next_page_token: String,
pub total_size: i32,
pub results: Vec<SearchSpaceResult>,
/* private fields */
}Expand description
Response with a list of spaces corresponding to the search spaces request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.spaces: Vec<Space>👎Deprecated
Deprecated: Please use the new results field instead.
A page of the requested spaces. This field will be populated only when
useAdminAccess is set to true and deprecated in favor of the new
results field.
next_page_token: StringA token that can be used to retrieve the next page. If this field is empty, there are no subsequent pages.
total_size: i32The total number of spaces that match the query, across all pages. If the result is over 10,000 spaces, this value is an estimate.
results: Vec<SearchSpaceResult>Output only. The list of search results that matched the query.
Implementations
Sourceimpl SearchSpacesResponse
impl SearchSpacesResponse
Sourcepub fn set_spaces<T, V>(self, v: T) -> Self
👎Deprecated
pub fn set_spaces<T, V>(self, v: T) -> Self
Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = SearchSpacesResponse::new().set_next_page_token("example");Sourcepub fn set_total_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_total_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_results<T, V>(self, v: T) -> Self
pub fn set_results<T, V>(self, v: T) -> Self