#[non_exhaustive]pub struct UpdateSpaceNotificationSettingRequest {
pub space_notification_setting: Option<SpaceNotificationSetting>,
pub update_mask: Option<FieldMask>,
/* private fields */
}Expand description
Request to update the space notification settings. Only supports updating notification setting for the calling user.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.space_notification_setting: Option<SpaceNotificationSetting>Required. The resource name for the space notification settings must be
populated in the form of
users/{user}/spaces/{space}/spaceNotificationSetting. Only fields
specified by update_mask are updated.
update_mask: Option<FieldMask>Required. Supported field paths:
-
notification_setting -
mute_setting
Implementations
Sourceimpl UpdateSpaceNotificationSettingRequest
impl UpdateSpaceNotificationSettingRequest
Sourcepub fn set_space_notification_setting<T>(self, v: T) -> Selfwhere
T: Into<SpaceNotificationSetting>,
pub fn set_space_notification_setting<T>(self, v: T) -> Selfwhere
T: Into<SpaceNotificationSetting>,
Sets the value of space_notification_setting.
Example
ⓘ
use google_chat_v1::model::SpaceNotificationSetting;
let x = UpdateSpaceNotificationSettingRequest::new().set_space_notification_setting(SpaceNotificationSetting::default()/* use setters */);Sourcepub fn set_or_clear_space_notification_setting<T>(self, v: Option<T>) -> Selfwhere
T: Into<SpaceNotificationSetting>,
pub fn set_or_clear_space_notification_setting<T>(self, v: Option<T>) -> Selfwhere
T: Into<SpaceNotificationSetting>,
Sets or clears the value of space_notification_setting.
Example
ⓘ
use google_chat_v1::model::SpaceNotificationSetting;
let x = UpdateSpaceNotificationSettingRequest::new().set_or_clear_space_notification_setting(Some(SpaceNotificationSetting::default()/* use setters */));
let x = UpdateSpaceNotificationSettingRequest::new().set_or_clear_space_notification_setting(None::<SpaceNotificationSetting>);Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateSpaceNotificationSettingRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateSpaceNotificationSettingRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateSpaceNotificationSettingRequest::new().set_or_clear_update_mask(None::<FieldMask>);Trait Implementations
Sourceimpl Clone for UpdateSpaceNotificationSettingRequest
impl Clone for UpdateSpaceNotificationSettingRequest
Sourcefn clone(&self) -> UpdateSpaceNotificationSettingRequest
fn clone(&self) -> UpdateSpaceNotificationSettingRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for UpdateSpaceNotificationSettingRequest
impl Default for UpdateSpaceNotificationSettingRequest
Sourcefn default() -> UpdateSpaceNotificationSettingRequest
fn default() -> UpdateSpaceNotificationSettingRequest
Returns the “default value” for a type. Read more
impl StructuralPartialEq for UpdateSpaceNotificationSettingRequest