#[non_exhaustive]pub struct UpdateSpaceReadStateRequest {
pub space_read_state: Option<SpaceReadState>,
pub update_mask: Option<FieldMask>,
/* private fields */
}Expand description
Request message for UpdateSpaceReadState API.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.space_read_state: Option<SpaceReadState>Required. The space read state and fields to update.
Only supports updating read state for the calling user.
To refer to the calling user, set one of the following:
-
The
mealias. For example,users/me/spaces/{space}/spaceReadState. -
Their Workspace email address. For example,
users/user@example.com/spaces/{space}/spaceReadState. -
Their user id. For example,
users/123456789/spaces/{space}/spaceReadState.
Format: users/{user}/spaces/{space}/spaceReadState
update_mask: Option<FieldMask>Required. The field paths to update. Currently supported field paths:
last_read_time
When the last_read_time is before the latest message create time, the
space appears as unread in the UI.
To mark the space as read, set last_read_time to any value later (larger)
than the latest message create time. The last_read_time is coerced to
match the latest message create time. Note that the space read state only
affects the read state of messages that are visible in the space’s
top-level conversation. Replies in threads are unaffected by this
timestamp, and instead rely on the thread read state.
Implementations
Sourceimpl UpdateSpaceReadStateRequest
impl UpdateSpaceReadStateRequest
Sourcepub fn set_space_read_state<T>(self, v: T) -> Selfwhere
T: Into<SpaceReadState>,
pub fn set_space_read_state<T>(self, v: T) -> Selfwhere
T: Into<SpaceReadState>,
Sets the value of space_read_state.
Example
use google_chat_v1::model::SpaceReadState;
let x = UpdateSpaceReadStateRequest::new().set_space_read_state(SpaceReadState::default()/* use setters */);Sourcepub fn set_or_clear_space_read_state<T>(self, v: Option<T>) -> Selfwhere
T: Into<SpaceReadState>,
pub fn set_or_clear_space_read_state<T>(self, v: Option<T>) -> Selfwhere
T: Into<SpaceReadState>,
Sets or clears the value of space_read_state.
Example
use google_chat_v1::model::SpaceReadState;
let x = UpdateSpaceReadStateRequest::new().set_or_clear_space_read_state(Some(SpaceReadState::default()/* use setters */));
let x = UpdateSpaceReadStateRequest::new().set_or_clear_space_read_state(None::<SpaceReadState>);Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateSpaceReadStateRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateSpaceReadStateRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateSpaceReadStateRequest::new().set_or_clear_update_mask(None::<FieldMask>);Trait Implementations
Sourceimpl Clone for UpdateSpaceReadStateRequest
impl Clone for UpdateSpaceReadStateRequest
Sourcefn clone(&self) -> UpdateSpaceReadStateRequest
fn clone(&self) -> UpdateSpaceReadStateRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more