#[non_exhaustive]pub struct UploadAttachmentRequest {
pub parent: String,
pub filename: String,
/* private fields */
}Expand description
Request to upload an attachment.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. Resource name of the Chat space in which the attachment is uploaded. Format “spaces/{space}”.
filename: StringRequired. The filename of the attachment, including the file extension.
Implementations
Sourceimpl UploadAttachmentRequest
impl UploadAttachmentRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self