User

Struct User 

#[non_exhaustive]
pub struct User { pub name: String, pub display_name: String, pub domain_id: String, pub type: Type, pub is_anonymous: bool, /* private fields */ }
A user in Google Chat. When returned as an output from a request, if your Chat app authenticates as a user, the output for a User resource only populates the user’s name and type.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Resource name for a Google Chat user.

Format: users/{user}. users/app can be used as an alias for the calling app bot user.

For human users, {user} is the same user identifier as:

  • the id for the Person in the People API. For example, users/123456789 in Chat API represents the same person as the 123456789 Person profile ID in People API.

  • the id for a user in the Admin SDK Directory API.

  • the user’s email address can be used as an alias for {user} in API requests. For example, if the People API Person profile ID for user@example.com is 123456789, you can use users/user@example.com as an alias to reference users/123456789. Only the canonical resource name (for example users/123456789) will be returned from the API.

display_name: String

Output only. The user’s display name.

domain_id: String

Unique identifier of the user’s Google Workspace domain.

type: Type

User type.

is_anonymous: bool

Output only. When true, the user is deleted or their profile is not visible.

Implementations

Source

impl User

pub fn new() -> Self

Creates a new default instance.

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = User::new().set_name("example");
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self

Sets the value of display_name.

Example
let x = User::new().set_display_name("example");
pub fn set_domain_id<T: Into<String>>(self, v: T) -> Self

Sets the value of domain_id.

Example
let x = User::new().set_domain_id("example");
pub fn set_type<T: Into<Type>>(self, v: T) -> Self

Sets the value of r#type.

Example
use google_chat_v1::model::user::Type;
let x0 = User::new().set_type(Type::Human);
let x1 = User::new().set_type(Type::Bot);
pub fn set_is_anonymous<T: Into<bool>>(self, v: T) -> Self

Sets the value of is_anonymous.

Example
let x = User::new().set_is_anonymous(true);