#[non_exhaustive]pub enum Icons {
Icon(Icon),
IconUrl(String),
}Expand description
The icon can be specified by an Icon enum or a URL.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Icon(Icon)
The icon specified by an enum that indices to an icon provided by
Chat API.
IconUrl(String)
The icon specified by a URL.