FormAction

Struct FormAction 

#[non_exhaustive]
pub struct FormAction { pub action_method_name: String, pub parameters: Vec<ActionParameter>, /* private fields */ }
A form action describes the behavior when the form is submitted. For example, you can invoke Apps Script to handle the form.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
action_method_name: String

The method name is used to identify which part of the form triggered the form submission. This information is echoed back to the Chat app as part of the card click event. You can use the same method name for several elements that trigger a common behavior.

parameters: Vec<ActionParameter>

List of action parameters.

Implementations

Source

impl FormAction

pub fn new() -> Self

Creates a new default instance.

pub fn set_action_method_name<T: Into<String>>(self, v: T) -> Self

Sets the value of action_method_name.

Example
let x = FormAction::new().set_action_method_name("example");
pub fn set_parameters<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<ActionParameter>,

Sets the value of parameters.

Example
use google_chat_v1::model::widget_markup::form_action::ActionParameter;
let x = FormAction::new()
    .set_parameters([
        ActionParameter::default()/* use setters */,
        ActionParameter::default()/* use (different) setters */,
    ]);