Image

Struct Image 

#[non_exhaustive]
pub struct Image { pub image_url: String, pub on_click: Option<OnClick>, pub aspect_ratio: f64, /* private fields */ }
An image that’s specified by a URL and can have an onclick action.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
image_url: String

The URL of the image.

on_click: Option<OnClick>

The onclick action.

aspect_ratio: f64

The aspect ratio of this image (width and height). This field lets you reserve the right height for the image while waiting for it to load. It’s not meant to override the built-in aspect ratio of the image. If unset, the server fills it by prefetching the image.

Implementations

Source

impl Image

pub fn new() -> Self

Creates a new default instance.

pub fn set_image_url<T: Into<String>>(self, v: T) -> Self

Sets the value of image_url.

Example
let x = Image::new().set_image_url("example");
pub fn set_on_click<T>(self, v: T) -> Self
where T: Into<OnClick>,

Sets the value of on_click.

Example
use google_chat_v1::model::widget_markup::OnClick;
let x = Image::new().set_on_click(OnClick::default()/* use setters */);
pub fn set_or_clear_on_click<T>(self, v: Option<T>) -> Self
where T: Into<OnClick>,

Sets or clears the value of on_click.

Example
use google_chat_v1::model::widget_markup::OnClick;
let x = Image::new().set_or_clear_on_click(Some(OnClick::default()/* use setters */));
let x = Image::new().set_or_clear_on_click(None::<OnClick>);
pub fn set_aspect_ratio<T: Into<f64>>(self, v: T) -> Self

Sets the value of aspect_ratio.

Example
let x = Image::new().set_aspect_ratio(42.0);