#[non_exhaustive]pub enum PositionOneof {
SortOrder(i32),
RelativePosition(Position),
}Expand description
Required. The new position of the section.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
SortOrder(i32)
Optional. The absolute position of the section in the list of sections. The position must be greater than 0. If the position is greater than the number of sections, the section will be appended to the end of the list. This operation inserts the section at the given position and shifts the original section at that position, and those below it, to the next position.
RelativePosition(Position)
Optional. The relative position of the section in the list of sections.