#[non_exhaustive]pub struct CreateMembershipRequest {
pub parent: String,
pub membership: Option<Membership>,
pub use_admin_access: bool,
/* private fields */
}Expand description
Request message for creating a membership.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The resource name of the space for which to create the membership.
Format: spaces/{space}
membership: Option<Membership>Required. The membership relation to create.
The memberType field must contain a user with the user.name and
user.type fields populated. The server will assign a resource name
and overwrite anything specified.
When a Chat app creates a membership relation for a human user, it must use certain authorization scopes and set specific values for certain fields:
-
When authenticating as a user, the
chat.membershipsauthorization scope is required. -
When authenticating as an app, the
chat.app.membershipsauthorization scope is required. -
Set
user.typetoHUMAN, and setuser.namewith formatusers/{user}, where{user}can be the email address for the user. For users in the same Workspace organization{user}can also be theidof the person from the People API, or theidfor the user in the Directory API. For example, if the People API Person profile ID foruser@example.comis123456789, you can add the user to the space by setting themembership.member.nametousers/user@example.comorusers/123456789.
Inviting users external to the Workspace organization that owns the space requires user authentication.
When a Chat app creates a membership relation for itself, it must
authenticate as a
user
and use the chat.memberships.app scope, set user.type to BOT, and set
user.name to users/app.
use_admin_access: boolOptional. When true, the method runs using the user’s Google Workspace
administrator privileges.
The calling user must be a Google Workspace administrator with the manage chat and spaces conversations privilege.
Requires the chat.admin.memberships OAuth 2.0
scope.
Creating app memberships or creating memberships for users outside the administrator’s Google Workspace organization isn’t supported using admin access.
Implementations
Sourceimpl CreateMembershipRequest
impl CreateMembershipRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_membership<T>(self, v: T) -> Selfwhere
T: Into<Membership>,
pub fn set_membership<T>(self, v: T) -> Selfwhere
T: Into<Membership>,
Sets the value of membership.
Example
use google_chat_v1::model::Membership;
let x = CreateMembershipRequest::new().set_membership(Membership::default()/* use setters */);Sourcepub fn set_or_clear_membership<T>(self, v: Option<T>) -> Selfwhere
T: Into<Membership>,
pub fn set_or_clear_membership<T>(self, v: Option<T>) -> Selfwhere
T: Into<Membership>,
Sets or clears the value of membership.
Example
use google_chat_v1::model::Membership;
let x = CreateMembershipRequest::new().set_or_clear_membership(Some(Membership::default()/* use setters */));
let x = CreateMembershipRequest::new().set_or_clear_membership(None::<Membership>);Sourcepub fn set_use_admin_access<T: Into<bool>>(self, v: T) -> Self
pub fn set_use_admin_access<T: Into<bool>>(self, v: T) -> Self
Sets the value of use_admin_access.
Example
let x = CreateMembershipRequest::new().set_use_admin_access(true);Trait Implementations
Sourceimpl Clone for CreateMembershipRequest
impl Clone for CreateMembershipRequest
Sourcefn clone(&self) -> CreateMembershipRequest
fn clone(&self) -> CreateMembershipRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more