#[non_exhaustive]pub struct CreateSpaceRequest {
pub space: Option<Space>,
pub request_id: String,
/* private fields */
}Expand description
A request to create a named space with no members.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.space: Option<Space>Required. The displayName and spaceType fields must be populated. Only
SpaceType.SPACE and SpaceType.GROUP_CHAT are supported.
SpaceType.GROUP_CHAT can only be used if importMode is set to true.
If you receive the error message ALREADY_EXISTS,
try a different displayName. An existing space within the Google
Workspace organization might already use this display name.
The space name is assigned on the server so anything specified in this
field will be ignored.
request_id: StringOptional. A unique identifier for this request. A random UUID is recommended. Specifying an existing request ID returns the space created with that ID instead of creating a new space. Specifying an existing request ID from the same Chat app with a different authenticated user returns an error.
Implementations
Sourceimpl CreateSpaceRequest
impl CreateSpaceRequest
Sourcepub fn set_or_clear_space<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_space<T>(self, v: Option<T>) -> Self
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateSpaceRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateSpaceRequest
impl Clone for CreateSpaceRequest
Sourcefn clone(&self) -> CreateSpaceRequest
fn clone(&self) -> CreateSpaceRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more