#[non_exhaustive]pub struct CustomEmoji {
pub name: String,
pub uid: String,
pub emoji_name: String,
pub temporary_image_uri: String,
pub payload: Option<CustomEmojiPayload>,
/* private fields */
}Expand description
Represents a custom emoji.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The resource name of the custom emoji, assigned by the server.
Format: customEmojis/{customEmoji}
uid: StringOutput only. Unique key for the custom emoji resource.
emoji_name: StringOptional. Immutable. User-provided name for the custom emoji, which is unique within the organization.
Required when the custom emoji is created, output only otherwise.
Emoji names must start and end with colons, must be lowercase and can only contain alphanumeric characters, hyphens, and underscores. Hyphens and underscores should be used to separate words and cannot be used consecutively.
Example: :valid-emoji-name:
temporary_image_uri: StringOutput only. A temporary image URL for the custom emoji, valid for at least 10 minutes. Note that this is not populated in the response when the custom emoji is created.
payload: Option<CustomEmojiPayload>Optional. Input only. Payload data. Required when the custom emoji is created.
Implementations
Sourceimpl CustomEmoji
impl CustomEmoji
Sourcepub fn set_emoji_name<T: Into<String>>(self, v: T) -> Self
pub fn set_emoji_name<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_temporary_image_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_temporary_image_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of temporary_image_uri.
Example
let x = CustomEmoji::new().set_temporary_image_uri("example");Sourcepub fn set_payload<T>(self, v: T) -> Selfwhere
T: Into<CustomEmojiPayload>,
pub fn set_payload<T>(self, v: T) -> Selfwhere
T: Into<CustomEmojiPayload>,
Sourcepub fn set_or_clear_payload<T>(self, v: Option<T>) -> Selfwhere
T: Into<CustomEmojiPayload>,
pub fn set_or_clear_payload<T>(self, v: Option<T>) -> Selfwhere
T: Into<CustomEmojiPayload>,