#[non_exhaustive]pub struct FindGroupChatsRequest {
pub users: Vec<String>,
pub page_size: i32,
pub page_token: String,
pub space_view: SpaceView,
/* private fields */
}Expand description
A request to get group chat spaces based on user resources.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.users: Vec<String>Optional. Resource names of all human users in group chat with the calling user. Chat apps can’t be included in the request.
The maximum number of users that can be specified in a single request is
49.
Format: users/{user}, where {user} is either the id for the
person from the
People API, or the id for the
user
in the Directory API. For example, to find all group chats with the calling
user and two other users, with People API profile IDs 123456789 and
987654321, you can use users/123456789 and users/987654321.
You can also use the email as an alias for {user}. For example,
users/example@gmail.com where example@gmail.com is the email of the
Google Chat user.
page_size: i32Optional. The maximum number of spaces to return. The service might return fewer than this value.
If unspecified, at most 10 spaces are returned.
The maximum value is 30. If you use a value more than 30, it’s automatically changed to 30.
Negative values return an INVALID_ARGUMENT error.
page_token: StringOptional. A page token, received from a previous call to find group chats. Provide this parameter to retrieve the subsequent page.
When paginating, all other parameters provided should match the call that provided the token. Passing different values may lead to unexpected results.
space_view: SpaceViewRequested space view type. If unset, defaults to
SPACE_VIEW_RESOURCE_NAME_ONLY. Requests that specify
SPACE_VIEW_EXPANDED must include scopes that allow reading space data,
for example,
https://www.googleapis.com/auth/chat.spaces or
https://www.googleapis.com/auth/chat.spaces.readonly.
Implementations
Sourceimpl FindGroupChatsRequest
impl FindGroupChatsRequest
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = FindGroupChatsRequest::new().set_page_token("example");Sourcepub fn set_space_view<T: Into<SpaceView>>(self, v: T) -> Self
pub fn set_space_view<T: Into<SpaceView>>(self, v: T) -> Self
Sets the value of space_view.
Example
use google_chat_v1::model::SpaceView;
let x0 = FindGroupChatsRequest::new().set_space_view(SpaceView::ResourceNameOnly);
let x1 = FindGroupChatsRequest::new().set_space_view(SpaceView::Expanded);Trait Implementations
Sourceimpl Clone for FindGroupChatsRequest
impl Clone for FindGroupChatsRequest
Sourcefn clone(&self) -> FindGroupChatsRequest
fn clone(&self) -> FindGroupChatsRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more