ListCustomEmojisRequest

Struct ListCustomEmojisRequest 

#[non_exhaustive]
pub struct ListCustomEmojisRequest { pub page_size: i32, pub page_token: String, pub filter: String, /* private fields */ }
A request to return a list of custom emojis.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
page_size: i32

Optional. The maximum number of custom emojis returned. The service can return fewer custom emojis than this value. If unspecified, the default value is 25. The maximum value is 200; values above 200 are changed to 200.

page_token: String

Optional. (If resuming from a previous query.)

A page token received from a previous list custom emoji call. Provide this to retrieve the subsequent page.

When paginating, the filter value should match the call that provided the page token. Passing a different value might lead to unexpected results.

filter: String

Optional. A query filter.

Supports filtering by creator.

To filter by creator, you must specify a valid value. Currently only creator("users/me") and NOT creator("users/me") are accepted to filter custom emojis by whether they were created by the calling user or not.

For example, the following query returns custom emojis created by the caller:

creator("users/me")

Invalid queries are rejected with an INVALID_ARGUMENT error.

Implementations

Source

impl ListCustomEmojisRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self

Sets the value of page_size.

Example
let x = ListCustomEmojisRequest::new().set_page_size(42);
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self

Sets the value of page_token.

Example
let x = ListCustomEmojisRequest::new().set_page_token("example");
pub fn set_filter<T: Into<String>>(self, v: T) -> Self

Sets the value of filter.

Example
let x = ListCustomEmojisRequest::new().set_filter("example");