#[non_exhaustive]pub struct ListMembershipsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
pub show_groups: bool,
pub show_invited: bool,
pub use_admin_access: bool,
/* private fields */
}Expand description
Request message for listing memberships.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The resource name of the space for which to fetch a membership list.
Format: spaces/{space}
page_size: i32Optional. The maximum number of memberships to return. The service might return fewer than this value.
If unspecified, at most 100 memberships are returned.
The maximum value is 1000. If you use a value more than 1000, it’s automatically changed to 1000.
Negative values return an INVALID_ARGUMENT error.
page_token: StringOptional. A page token, received from a previous call to list memberships. Provide this parameter to retrieve the subsequent page.
When paginating, all other parameters provided should match the call that provided the page token. Passing different values to the other parameters might lead to unexpected results.
filter: StringOptional. A query filter.
You can filter memberships by a member’s role
(role)
and type
(member.type).
To filter by role, set role to ROLE_MEMBER or ROLE_MANAGER.
To filter by type, set member.type to HUMAN or BOT. You can also
filter for member.type using the != operator.
To filter by both role and type, use the AND operator. To filter by
either role or type, use the OR operator.
Either member.type = "HUMAN" or member.type != "BOT" is required
when use_admin_access is set to true. Other member type filters will be
rejected.
For example, the following queries are valid:
role = "ROLE_MANAGER" OR role = "ROLE_MEMBER"
member.type = "HUMAN" AND role = "ROLE_MANAGER"
member.type != "BOT"The following queries are invalid:
member.type = "HUMAN" AND member.type = "BOT"
role = "ROLE_MANAGER" AND role = "ROLE_MEMBER"Invalid queries are rejected by the server with an INVALID_ARGUMENT
error.
show_groups: boolOptional. When true, also returns memberships associated with a
Google Group, in
addition to other types of memberships. If a
filter is set,
Google Group
memberships that don’t match the filter criteria aren’t returned.
show_invited: boolOptional. When true, also returns memberships associated with
invited members, in
addition to other types of memberships. If a
filter is set,
invited memberships
that don’t match the filter criteria aren’t returned.
Currently requires user authentication.
use_admin_access: boolOptional. When true, the method runs using the user’s Google Workspace
administrator privileges.
The calling user must be a Google Workspace administrator with the manage chat and spaces conversations privilege.
Requires either the chat.admin.memberships.readonly or
chat.admin.memberships OAuth 2.0
scope.
Listing app memberships in a space isn’t supported when using admin access.
Implementations
Sourceimpl ListMembershipsRequest
impl ListMembershipsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListMembershipsRequest::new().set_page_token("example");Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_show_groups<T: Into<bool>>(self, v: T) -> Self
pub fn set_show_groups<T: Into<bool>>(self, v: T) -> Self
Sets the value of show_groups.
Example
let x = ListMembershipsRequest::new().set_show_groups(true);Sourcepub fn set_show_invited<T: Into<bool>>(self, v: T) -> Self
pub fn set_show_invited<T: Into<bool>>(self, v: T) -> Self
Sets the value of show_invited.
Example
let x = ListMembershipsRequest::new().set_show_invited(true);Sourcepub fn set_use_admin_access<T: Into<bool>>(self, v: T) -> Self
pub fn set_use_admin_access<T: Into<bool>>(self, v: T) -> Self
Sets the value of use_admin_access.
Example
let x = ListMembershipsRequest::new().set_use_admin_access(true);Trait Implementations
Sourceimpl Clone for ListMembershipsRequest
impl Clone for ListMembershipsRequest
Sourcefn clone(&self) -> ListMembershipsRequest
fn clone(&self) -> ListMembershipsRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more