#[non_exhaustive]pub struct ListMessagesRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
pub order_by: String,
pub show_deleted: bool,
pub markup_syntax: MarkupSyntax,
/* private fields */
}Expand description
Lists messages in the specified space, that the user is a member of.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The resource name of the space to list messages from.
Format: spaces/{space}
page_size: i32Optional. The maximum number of messages returned. The service might return fewer messages than this value.
If unspecified, at most 25 are returned.
The maximum value is 1000. If you use a value more than 1000, it’s automatically changed to 1000.
Negative values return an INVALID_ARGUMENT error.
page_token: StringOptional. A page token received from a previous list messages call. Provide this parameter to retrieve the subsequent page.
When paginating, all other parameters provided should match the call that provided the page token. Passing different values to the other parameters might lead to unexpected results.
filter: StringOptional. A query filter.
You can filter messages by date (create_time) and thread (thread.name).
To filter messages by the date they were created, specify the create_time
with a timestamp in RFC-3339
format and double quotation marks. For example,
"2023-04-21T11:30:00-04:00". You can use the greater than operator > to
list messages that were created after a timestamp, or the less than
operator < to list messages that were created before a timestamp. To
filter messages within a time interval, use the AND operator between two
timestamps.
To filter by thread, specify the thread.name, formatted as
spaces/{space}/threads/{thread}. You can only specify one
thread.name per query.
To filter by both thread and date, use the AND operator in your query.
For example, the following queries are valid:
create_time > "2012-04-21T11:30:00-04:00"
create_time > "2012-04-21T11:30:00-04:00" AND
thread.name = spaces/AAAAAAAAAAA/threads/123
create_time > "2012-04-21T11:30:00+00:00" AND
create_time < "2013-01-01T00:00:00+00:00" AND
thread.name = spaces/AAAAAAAAAAA/threads/123
thread.name = spaces/AAAAAAAAAAA/threads/123Invalid queries are rejected by the server with an INVALID_ARGUMENT
error.
order_by: StringOptional. How the list of messages is ordered. Specify a value to order by an ordering operation. Valid ordering operation values are as follows:
-
ASCfor ascending. -
DESCfor descending.
The default ordering is create_time ASC.
show_deleted: boolOptional. Whether to include deleted messages. Deleted messages include deleted time and metadata about their deletion, but message content is unavailable.
markup_syntax: MarkupSyntaxOptional. Specifies the desired output syntax for the Chat message
formatted_text field.
Implementations
Sourceimpl ListMessagesRequest
impl ListMessagesRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListMessagesRequest::new().set_page_token("example");Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_order_by<T: Into<String>>(self, v: T) -> Self
pub fn set_order_by<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_show_deleted<T: Into<bool>>(self, v: T) -> Self
pub fn set_show_deleted<T: Into<bool>>(self, v: T) -> Self
Sets the value of show_deleted.
Example
let x = ListMessagesRequest::new().set_show_deleted(true);Sourcepub fn set_markup_syntax<T: Into<MarkupSyntax>>(self, v: T) -> Self
pub fn set_markup_syntax<T: Into<MarkupSyntax>>(self, v: T) -> Self
Sets the value of markup_syntax.
Example
use google_chat_v1::model::MarkupSyntax;
let x0 = ListMessagesRequest::new().set_markup_syntax(MarkupSyntax::Chat);
let x1 = ListMessagesRequest::new().set_markup_syntax(MarkupSyntax::Markdown);Trait Implementations
Sourceimpl Clone for ListMessagesRequest
impl Clone for ListMessagesRequest
Sourcefn clone(&self) -> ListMessagesRequest
fn clone(&self) -> ListMessagesRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more