#[non_exhaustive]pub struct ListSectionItemsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
/* private fields */
}Expand description
Request message for listing section items.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent, which is the section resource name that owns this collection of section items. Only supports listing section items for the calling user.
When you’re filtering by space, use the wildcard - to search across all
sections. For example, users/{user}/sections/-.
Format: users/{user}/sections/{section}
page_size: i32Optional. The maximum number of section items to return. The service may return fewer than this value.
If unspecified, at most 10 section items will be returned.
The maximum value is 100. If you use a value more than 100, it’s automatically changed to 100.
Negative values return an INVALID_ARGUMENT error.
page_token: StringOptional. A page token, received from a previous list section items call. Provide this to retrieve the subsequent page.
When paginating, all other parameters provided should match the call that provided the page token. Passing different values to the other parameters might lead to unexpected results.
filter: StringOptional. A query filter.
Currently only supports filtering by space.
For example, space = spaces/{space}.
Invalid queries are rejected with an INVALID_ARGUMENT error.
Implementations
Sourceimpl ListSectionItemsRequest
impl ListSectionItemsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListSectionItemsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListSectionItemsRequest
impl Clone for ListSectionItemsRequest
Sourcefn clone(&self) -> ListSectionItemsRequest
fn clone(&self) -> ListSectionItemsRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more