ListSectionsRequest

Struct ListSectionsRequest 

#[non_exhaustive]
pub struct ListSectionsRequest { pub parent: String, pub page_size: i32, pub page_token: String, /* private fields */ }
Request message for listing sections.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
parent: String

Required. The parent, which is the user resource name that owns this collection of sections. Only supports listing sections for the calling user. To refer to the calling user, set one of the following:

  • The me alias. For example, users/me.

  • Their Workspace email address. For example, users/user@example.com.

  • Their user id. For example, users/123456789.

Format: users/{user}

page_size: i32

Optional. The maximum number of sections to return. The service may return fewer than this value.

If unspecified, at most 10 sections will be returned.

The maximum value is 100. If you use a value more than 100, it’s automatically changed to 100.

Negative values return an INVALID_ARGUMENT error.

page_token: String

Optional. A page token, received from a previous list sections call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided should match the call that provided the page token. Passing different values to the other parameters might lead to unexpected results.

Implementations

Source

impl ListSectionsRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_parent<T: Into<String>>(self, v: T) -> Self

Sets the value of parent.

Example
let x = ListSectionsRequest::new().set_parent("example");
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self

Sets the value of page_size.

Example
let x = ListSectionsRequest::new().set_page_size(42);
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self

Sets the value of page_token.

Example
let x = ListSectionsRequest::new().set_page_token("example");