#[non_exhaustive]pub struct ListSpaceEventsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
/* private fields */
}Expand description
Request message for listing space events.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. Resource name of the Google Chat space where the events occurred.
Format: spaces/{space}.
page_size: i32Optional. The maximum number of space events returned. The service might return fewer than this value.
Negative values return an INVALID_ARGUMENT error.
page_token: StringOptional. A page token, received from a previous list space events call. Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to list space events must match the call that provided the page token. Passing different values to the other parameters might lead to unexpected results.
filter: StringRequired. A query filter.
You must specify at least one event type (event_type)
using the has : operator. To filter by multiple event types, use the OR
operator. Omit batch event types in your filter. The request automatically
returns any related batch events. For example, if you filter by new
reactions
(google.workspace.chat.reaction.v1.created), the server also returns
batch new reactions events
(google.workspace.chat.reaction.v1.batchCreated). For a list of supported
event types, see the SpaceEvents reference
documentation.
Optionally, you can also filter by start time (start_time) and
end time (end_time):
start_time: Exclusive timestamp from which to start listing space events. You can list events that occurred up to 28 days ago. If unspecified, lists space events from the past 28 days.end_time: Inclusive timestamp until which space events are listed. If unspecified, lists events up to the time of the request.
To specify a start or end time, use the equals = operator and format in
RFC-3339. To filter by both
start_time and end_time, use the AND operator.
For example, the following queries are valid:
start_time="2023-08-23T19:20:33+00:00" AND
end_time="2023-08-23T19:21:54+00:00"start_time="2023-08-23T19:20:33+00:00" AND
(event_types:"google.workspace.chat.space.v1.updated" OR
event_types:"google.workspace.chat.message.v1.created")The following queries are invalid:
start_time="2023-08-23T19:20:33+00:00" OR
end_time="2023-08-23T19:21:54+00:00"event_types:"google.workspace.chat.space.v1.updated" AND
event_types:"google.workspace.chat.message.v1.created"Invalid queries are rejected by the server with an INVALID_ARGUMENT
error.
Implementations
Sourceimpl ListSpaceEventsRequest
impl ListSpaceEventsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListSpaceEventsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListSpaceEventsRequest
impl Clone for ListSpaceEventsRequest
Sourcefn clone(&self) -> ListSpaceEventsRequest
fn clone(&self) -> ListSpaceEventsRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more