#[non_exhaustive]pub struct SearchSpacesRequest {
pub use_admin_access: bool,
pub page_size: i32,
pub page_token: String,
pub query: String,
pub order_by: String,
/* private fields */
}Expand description
Request to search for a list of spaces based on a query.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.use_admin_access: boolWhen true, the method runs using the user’s Google Workspace
administrator privileges.
The calling user must be a Google Workspace administrator with the manage chat and spaces conversations privilege.
Requires either the chat.admin.spaces.readonly or chat.admin.spaces
OAuth 2.0
scope.
page_size: i32The maximum number of spaces to return. The service may return fewer than this value.
If unspecified, at most 100 spaces are returned.
The maximum value is 1000. If you use a value more than 1000, it’s automatically changed to 1000.
page_token: StringA token, received from the previous search spaces call. Provide this parameter to retrieve the subsequent page.
When paginating, all other parameters provided should match the call that provided the page token. Passing different values to the other parameters might lead to unexpected results.
query: StringRequired. A search query.
You can search by using the following parameters when useAdminAccess
is set to true:
create_timecustomerdisplay_nameexternal_user_allowedlast_active_timespace_history_statespace_type
When useAdminAccess is set to false:
display_nameexternal_user_allowedspace_type
create_time and last_active_time accept a timestamp in
RFC-3339 format and the supported
comparison operators are: =, <, >, <=, >=.
customer is required when useAdminAccess is set to true, and is
used to indicate which customer to fetch spaces from.
customers/my_customer is the only supported value.
display_name only accepts the HAS (:) operator. The text to
match is first tokenized into tokens and each token is prefix-matched
case-insensitively and independently as a substring anywhere in the space’s
display_name. For example, Fun Eve matches Fun event or The evening was fun, but not notFun event or even. When useAdminAccess
is set to false, display_name is required to retrieve meaningful
results. Otherwise, the default behavior is to return an empty response.
external_user_allowed accepts either true or false.
space_history_state only accepts values from the [historyState]
(https://developers.google.com/workspace/chat/api/reference/rest/v1/spaces#Space.HistoryState)
field of a space resource.
space_type is required and the only valid value is SPACE.
Across different fields, only AND operators are supported. A valid
example is space_type = "SPACE" AND display_name:"Hello" and an invalid
example is space_type = "SPACE" OR display_name:"Hello".
Among the same field,
space_type doesn’t support AND or OR operators.
display_name, ‘space_history_state’, and ‘external_user_allowed’ only
support OR operators.
last_active_time and create_time support both AND and OR operators.
AND can only be used to represent an interval, such as last_active_time < "2022-01-01T00:00:00+00:00" AND last_active_time > "2023-01-01T00:00:00+00:00".
The following example queries are valid when useAdminAccess is set to
true:
customer = "customers/my_customer" AND space_type = "SPACE"
customer = "customers/my_customer" AND space_type = "SPACE" AND
display_name:"Hello World"
customer = "customers/my_customer" AND space_type = "SPACE" AND
(last_active_time < "2020-01-01T00:00:00+00:00" OR last_active_time >
"2022-01-01T00:00:00+00:00")
customer = "customers/my_customer" AND space_type = "SPACE" AND
(display_name:"Hello World" OR display_name:"Fun event") AND
(last_active_time > "2020-01-01T00:00:00+00:00" AND last_active_time <
"2022-01-01T00:00:00+00:00")
customer = "customers/my_customer" AND space_type = "SPACE" AND
(create_time > "2019-01-01T00:00:00+00:00" AND create_time <
"2020-01-01T00:00:00+00:00") AND (external_user_allowed = "true") AND
(space_history_state = "HISTORY_ON" OR space_history_state = "HISTORY_OFF")The following example queries are valid when useAdminAccess is set to
false:
display_name:"Hello World" AND space_type = "SPACE"
(display_name:"Hello" OR display_name:"Fun") AND space_type = "SPACE"
(external_user_allowed = "true" AND space_type = "SPACE") // Returns an
empty response.
(external_user_allowed = "true" AND display_name:"Hello" AND space_type =
"SPACE")order_by: StringOptional. How the list of spaces is ordered.
Supported attributes to order by are:
membership_count.joined_direct_human_user_count— Denotes the count of human users that have directly joined a space.last_active_time— Denotes the time when last eligible item is added to any topic of this space.create_time— Denotes the time of the space creation.
When useAdminAccess is false, only create_time and relevance are
supported for ordering. Only DESC is supported for these fields in
non-admin searches.
Valid ordering operation values are:
-
ASCfor ascending. Default value. -
DESCfor descending.
The supported syntax are when useAdminAccess is set to true:
membership_count.joined_direct_human_user_count DESCmembership_count.joined_direct_human_user_count ASClast_active_time DESClast_active_time ASCcreate_time DESCcreate_time ASC
When useAdminAccess is set to false:
create_time DESCrelevance DESCDeveloper Preview.
Implementations
Sourceimpl SearchSpacesRequest
impl SearchSpacesRequest
Sourcepub fn set_use_admin_access<T: Into<bool>>(self, v: T) -> Self
pub fn set_use_admin_access<T: Into<bool>>(self, v: T) -> Self
Sets the value of use_admin_access.
Example
let x = SearchSpacesRequest::new().set_use_admin_access(true);Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = SearchSpacesRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for SearchSpacesRequest
impl Clone for SearchSpacesRequest
Sourcefn clone(&self) -> SearchSpacesRequest
fn clone(&self) -> SearchSpacesRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more