#[non_exhaustive]pub struct Thread {
pub name: String,
pub thread_key: String,
/* private fields */
}Expand description
A thread in a Google Chat space. For example usage, see Start or reply to a message thread.
If you specify a thread when creating a message, you can set the
messageReplyOption
field to determine what happens if no matching thread is found.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. Resource name of the thread.
Example: spaces/{space}/threads/{thread}
thread_key: StringOptional. Input for creating or updating a thread. Otherwise, output only. ID for the thread. Supports up to 4000 characters.
This ID is unique to the Chat app that sets it. For example, if
multiple Chat apps create a message using the same thread key,
the messages are posted in different threads. To reply in a
thread created by a person or another Chat app, specify the thread name
field instead.
Implementations