#[non_exhaustive]pub struct UpdateSpaceRequest {
pub space: Option<Space>,
pub update_mask: Option<FieldMask>,
pub use_admin_access: bool,
/* private fields */
}Expand description
A request to update a single space.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.space: Option<Space>Required. Space with fields to be updated. Space.name must be
populated in the form of spaces/{space}. Only fields
specified by update_mask are updated.
update_mask: Option<FieldMask>Required. The updated field paths, comma separated if there are multiple.
You can update the following fields for a space:
space_details: Updates the space’s description and guidelines. You must
pass both description and guidelines in the update request as
SpaceDetails. If you only want to
update one of the fields, pass the existing value for the other field.
display_name: Only supports updating the display name for spaces where
spaceType field is SPACE.
If you receive the error message ALREADY_EXISTS, try a different
value. An existing space within the
Google Workspace organization might already use this display name.
space_type: Only supports changing a GROUP_CHAT space type to
SPACE. Include display_name together
with space_type in the update mask and ensure that the specified space
has a non-empty display name and the SPACE space type. Including the
space_type mask and the SPACE type in the specified space when updating
the display name is optional if the existing space already has the SPACE
type. Trying to update the space type in other ways results in an invalid
argument error.
space_type is not supported with useAdminAccess.
space_history_state: Updates space history
settings by turning
history on or off for the space. Only supported if history settings are
enabled for the Google Workspace organization. To update the
space history state, you must omit all other field masks in your request.
space_history_state is not supported with useAdminAccess.
access_settings.audience: Updates the access
setting of who can
discover the space, join the space, and preview the messages in named space
where spaceType field is SPACE. If the existing space has a
target audience, you can remove the audience and restrict space access by
omitting a value for this field mask. To update access settings for a
space, the authenticating user must be a space manager and omit all other
field masks in your request. You can’t update this field if the space is in
import
mode.
To learn more, see Make a space discoverable to specific
users.
access_settings.audience is not supported with useAdminAccess.
access_settings.access_permission_settings: Updates the access
permission
settings of who can
discover and join the space where spaceType field is SPACE. Principals
allowed to join the space must also be allowed to discover it. To update
access permission settings for a space, the authenticating user must be a
space manager or assistant manager and omit all other field masks in the
request. You can’t update this field if the space is in import
mode.
To learn more, see Make a space discoverable to specific
users.
access_settings.access_permission_settings is not supported with
useAdminAccess.
The supported field masks include:
access_settings.access_permission_settings.discoverSpaceSettingaccess_settings.access_permission_settings.joinSpaceSetting
permission_settings: Supports changing the
permission settings
of a space.
When updating permission settings, you can only specify
permissionSettings field masks; you cannot update other field masks
at the same time.
The supported field masks include:
permission_settings.manageMembersAndGroupspermission_settings.modifySpaceDetailspermission_settings.toggleHistorypermission_settings.useAtMentionAllpermission_settings.manageAppspermission_settings.manageWebhookspermission_settings.replyMessages
use_admin_access: boolOptional. When true, the method runs using the user’s Google Workspace
administrator privileges.
The calling user must be a Google Workspace administrator with the manage chat and spaces conversations privilege.
Requires the chat.admin.spaces OAuth 2.0
scope.
Some FieldMask values are not supported using admin access. For details,
see the description of update_mask.
Implementations
Sourceimpl UpdateSpaceRequest
impl UpdateSpaceRequest
Sourcepub fn set_or_clear_space<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_space<T>(self, v: Option<T>) -> Self
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateSpaceRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateSpaceRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateSpaceRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_use_admin_access<T: Into<bool>>(self, v: T) -> Self
pub fn set_use_admin_access<T: Into<bool>>(self, v: T) -> Self
Sets the value of use_admin_access.
Example
let x = UpdateSpaceRequest::new().set_use_admin_access(true);Trait Implementations
Sourceimpl Clone for UpdateSpaceRequest
impl Clone for UpdateSpaceRequest
Sourcefn clone(&self) -> UpdateSpaceRequest
fn clone(&self) -> UpdateSpaceRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more