A user in Google Chat.
When returned as an output from a request, if your Chat app authenticates as
a
user,
the output for a User resource only populates the user’s name and type.
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
Format: users/{user}. users/app can be used as an alias for the calling
app bot user.
For human users, {user} is the same
user identifier as:
the id for the
Person in the
People API. For example, users/123456789 in Chat API represents the same
person as the 123456789 Person profile ID in People API.
the user’s email address can be used as an alias for {user} in API
requests. For example, if the People API Person profile ID for
user@example.com is 123456789, you can use users/user@example.com as
an alias to reference users/123456789. Only the canonical resource name
(for example users/123456789) will be returned from the API.