KeyValue

Struct KeyValue 

#[non_exhaustive]
pub struct KeyValue { pub top_label: String, pub content: String, pub content_multiline: bool, pub bottom_label: String, pub on_click: Option<OnClick>, pub icons: Option<Icons>, pub control: Option<Control>, /* private fields */ }
A UI element contains a key (label) and a value (content). This element can also contain some actions such as onclick button.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
top_label: String

The text of the top label. Formatted text supported. For more information about formatting text, see Formatting text in Google Chat apps and Formatting text in Google Workspace Add-ons.

content: String

The text of the content. Formatted text supported and always required. For more information about formatting text, see Formatting text in Google Chat apps and Formatting text in Google Workspace Add-ons.

content_multiline: bool

If the content should be multiline.

bottom_label: String

The text of the bottom label. Formatted text supported. For more information about formatting text, see Formatting text in Google Chat apps and Formatting text in Google Workspace Add-ons.

on_click: Option<OnClick>

The onclick action. Only the top label, bottom label, and content region are clickable.

icons: Option<Icons>

At least one of icons, top_label and bottom_label must be defined.

control: Option<Control>

A control widget. You can set either button or switch_widget, but not both.

Implementations

Source

impl KeyValue

pub fn new() -> Self

Creates a new default instance.

pub fn set_top_label<T: Into<String>>(self, v: T) -> Self

Sets the value of top_label.

Example
let x = KeyValue::new().set_top_label("example");
pub fn set_content<T: Into<String>>(self, v: T) -> Self

Sets the value of content.

Example
let x = KeyValue::new().set_content("example");
pub fn set_content_multiline<T: Into<bool>>(self, v: T) -> Self

Sets the value of content_multiline.

Example
let x = KeyValue::new().set_content_multiline(true);
pub fn set_bottom_label<T: Into<String>>(self, v: T) -> Self

Sets the value of bottom_label.

Example
let x = KeyValue::new().set_bottom_label("example");
pub fn set_on_click<T>(self, v: T) -> Self
where T: Into<OnClick>,

Sets the value of on_click.

Example
use google_chat_v1::model::widget_markup::OnClick;
let x = KeyValue::new().set_on_click(OnClick::default()/* use setters */);
pub fn set_or_clear_on_click<T>(self, v: Option<T>) -> Self
where T: Into<OnClick>,

Sets or clears the value of on_click.

Example
use google_chat_v1::model::widget_markup::OnClick;
let x = KeyValue::new().set_or_clear_on_click(Some(OnClick::default()/* use setters */));
let x = KeyValue::new().set_or_clear_on_click(None::<OnClick>);
pub fn set_icons<T: Into<Option<Icons>>>(self, v: T) -> Self

Sets the value of icons.

Note that all the setters affecting icons are mutually exclusive.

Example
use google_chat_v1::model::widget_markup::Icon;
let x0 = KeyValue::new().set_icons(Some(
    google_chat_v1::model::widget_markup::key_value::Icons::Icon(Icon::Airplane)));
let x1 = KeyValue::new().set_icons(Some(
    google_chat_v1::model::widget_markup::key_value::Icons::Icon(Icon::Bookmark)));
let x2 = KeyValue::new().set_icons(Some(
    google_chat_v1::model::widget_markup::key_value::Icons::Icon(Icon::Bus)));
pub fn icon(&self) -> Option<&Icon>

The value of icons if it holds a Icon, None if the field is not set or holds a different branch.

pub fn set_icon<T: Into<Icon>>(self, v: T) -> Self

Sets the value of icons to hold a Icon.

Note that all the setters affecting icons are mutually exclusive.

Example
use google_chat_v1::model::widget_markup::Icon;
let x0 = KeyValue::new().set_icon(Icon::Airplane);
let x1 = KeyValue::new().set_icon(Icon::Bookmark);
let x2 = KeyValue::new().set_icon(Icon::Bus);
assert!(x0.icon().is_some());
assert!(x0.icon_url().is_none());
assert!(x1.icon().is_some());
assert!(x1.icon_url().is_none());
assert!(x2.icon().is_some());
assert!(x2.icon_url().is_none());
pub fn icon_url(&self) -> Option<&String>

The value of icons if it holds a IconUrl, None if the field is not set or holds a different branch.

pub fn set_icon_url<T: Into<String>>(self, v: T) -> Self

Sets the value of icons to hold a IconUrl.

Note that all the setters affecting icons are mutually exclusive.

Example
let x = KeyValue::new().set_icon_url("example");
assert!(x.icon_url().is_some());
assert!(x.icon().is_none());
pub fn set_control<T: Into<Option<Control>>>(self, v: T) -> Self

Sets the value of control.

Note that all the setters affecting control are mutually exclusive.

Example
use google_chat_v1::model::widget_markup::Button;
let x = KeyValue::new().set_control(Some(
    google_chat_v1::model::widget_markup::key_value::Control::Button(Button::default().into())));
pub fn button(&self) -> Option<&Box<Button>>

The value of control if it holds a Button, None if the field is not set or holds a different branch.

pub fn set_button<T: Into<Box<Button>>>(self, v: T) -> Self

Sets the value of control to hold a Button.

Note that all the setters affecting control are mutually exclusive.

Example
use google_chat_v1::model::widget_markup::Button;
let x = KeyValue::new().set_button(Button::default()/* use setters */);
assert!(x.button().is_some());